@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -24,8 +24,7 @@ editors_trait = List(EditorFactory)
 
 
 class CompoundEditor(EditorFactory):
-    """ Editor factory for compound editors.
-    """
+    """Editor factory for compound editors."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
