@@ -1,10 +1,20 @@
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 from traits.api import Bool, List, Str
-from .date_editor import CellFormat, DateEditor
+
+from traitsui.editors.date_editor import DateEditor
 
 
-class ToolkitEditorFactory(DateEditor):
-    """ A DateEditor that can show sets of dates in different styles.
-    """
+class StyledDateEditor(DateEditor):
+    """A DateEditor that can show sets of dates in different styles."""
 
     #: The name of a dictionary on the object that maps names to groups
     #: (list/tuples) of datetime.date objects.  Each of these groups can be
@@ -27,4 +37,5 @@ class ToolkitEditorFactory(DateEditor):
     relative_dates = List()
 
 
-StyledDateEditor = ToolkitEditorFactory
+# This alias is deprecated and will be removed in TraitsUI 8.
+ToolkitEditorFactory = StyledDateEditor
