@@ -1,24 +1,16 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2008, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/21/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ Defines the table editor factory for all traits user interface toolkits.
 """
 
-
-
 from traits.api import (
     Int,
     Float,
@@ -33,19 +25,18 @@ from traits.api import (
     Callable,
     Range,
     Trait,
-    on_trait_change,
+    observe,
 )
 
-from ..editor_factory import EditorFactory
-from ..handler import Handler
-from ..helper import Orientation
-from ..item import Item
-from ..table_filter import TableFilter
-from ..toolkit_traits import Color, Font
-from ..ui_traits import AView
-from ..view import View
-from .enum_editor import EnumEditor
-
+from traitsui.editor_factory import EditorFactory
+from traitsui.editors.enum_editor import EnumEditor
+from traitsui.handler import Handler
+from traitsui.helper import Orientation
+from traitsui.item import Item
+from traitsui.table_filter import TableFilter
+from traitsui.toolkit_traits import Color, Font
+from traitsui.ui_traits import AView
+from traitsui.view import View
 
 # The filter used to indicate that the user wants to customize the current
 # filter
@@ -59,9 +50,8 @@ customize_filter = TableFilter(name="Customize...")
 BoolOrCallable = Trait(False, Bool, Callable)
 
 
-class ToolkitEditorFactory(EditorFactory):
-    """ Editor factory for table editors.
-    """
+class TableEditor(EditorFactory):
+    """Editor factory for table editors."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -79,11 +69,12 @@ class ToolkitEditorFactory(EditorFactory):
     #: The desired number of visible rows in the table
     rows = Int()
 
-    #: The optional extended name of the trait used to specify an external filter
-    #: for the table data. The value of the trait must either be an instance of
-    #: TableEditor, a callable that accepts one argument (a table row) and
-    #: returns True or False to indicate whether the specified object passes the
-    #: filter or not, or **None** to indicate that no filter is to be applied:
+    #: The optional extended name of the trait used to specify an external
+    #: filter for the table data. The value of the trait must either be an
+    #: instance of TableEditor, a callable that accepts one argument
+    #: (a table row) and returns True or False to indicate whether the
+    #: specified object passes the filter or not, or **None** to indicate that
+    #: no filter is to be applied:
     filter_name = Str()
 
     #: Initial filter that should be applied to the table
@@ -226,13 +217,14 @@ class ToolkitEditorFactory(EditorFactory):
     #: Color to use for text in labels
     label_color = Color(default=None, allow_none=True)
 
-    #: Color to use for label backgrounds. Some Qt styles (eg. MacOS) ignore this.
+    #: Color to use for label backgrounds. Some Qt styles (eg. MacOS) ignore
+    #: this.
     label_bg_color = Color(default=None, allow_none=True)
 
-    #: Background color of selected item.  Does not work on Qt.
+    #: Background color of selected item.
     selection_bg_color = Color(default=None, allow_none=True)
 
-    #: Color of selected text.  Does not work on Qt.
+    #: Color of selected text.
     selection_color = Color(default=None, allow_none=True)
 
     #: Height (in pixels) of column labels
@@ -248,8 +240,8 @@ class ToolkitEditorFactory(EditorFactory):
     #: currently passing the table filter are synced with:
     filtered_indices = Str()
 
-    #: The selection mode of the table. The meaning of the various values are as
-    #: follows:
+    #: The selection mode of the table. The meaning of the various values are
+    #: as follows:
     #:
     #: row
     #:   Entire rows are selected. At most one row can be selected at once.
@@ -277,9 +269,9 @@ class ToolkitEditorFactory(EditorFactory):
     selected_indices = Str()
 
     #: The optional extended trait name of the trait that should be assigned
-    #: an ( object, column ) tuple when a table cell is clicked on (Note: If you
-    #: want to receive repeated clicks on the same cell, make sure the trait is
-    #: defined as an Event):
+    #: an ( object, column ) tuple when a table cell is clicked on (Note: If
+    #: you want to receive repeated clicks on the same cell, make sure the
+    #: trait is defined as an Event):
     click = Str()
 
     #: The optional extended trait name of the trait that should be assigned
@@ -392,24 +384,22 @@ class ToolkitEditorFactory(EditorFactory):
     # -------------------------------------------------------------------------
 
     def readonly_editor(self, ui, object, name, description, parent):
-        """ Generates an "editor" that is read-only.
+        """Generates an "editor" that is read-only.
         Overridden to set the value of the editable trait to False before
         generating the editor.
 
         """
         self.editable = False
-        return super(ToolkitEditorFactory, self).readonly_editor(
-            ui, object, name, description, parent
-        )
+        return super().readonly_editor(ui, object, name, description, parent)
 
     # -------------------------------------------------------------------------
     #  Event handlers:
     # -------------------------------------------------------------------------
 
-    @on_trait_change("filters[]")
-    def _update_filter_editor(self, object, name, old, new):
-        """ Handles the set of filters associated with the editor's factory
-            being changed.
+    @observe("filters.items")
+    def _update_filter_editor(self, event):
+        """Handles the set of filters associated with the editor's factory
+        being changed.
         """
         values = {None: "000:No filter"}
         i = 0
@@ -424,8 +414,8 @@ class ToolkitEditorFactory(EditorFactory):
             self._filter_editor.values = values
 
 
-# Define the TableEditor class
-TableEditor = ToolkitEditorFactory
+# This alias is deprecated and will be removed in TraitsUI 8.
+ToolkitEditorFactory = TableEditor
 
 # -------------------------------------------------------------------------
 #  Base class for toolkit-specific editors
@@ -433,8 +423,7 @@ TableEditor = ToolkitEditorFactory
 
 
 class BaseTableEditor(object):
-    """ Base class for toolkit-specific editors.
-    """
+    """Base class for toolkit-specific editors."""
 
     # -------------------------------------------------------------------------
     #  Interface for toolkit-specific editors:
@@ -442,7 +431,7 @@ class BaseTableEditor(object):
 
     def set_menu_context(self, selection, object, column):
         """Call before creating a context menu for a cell, then set self as the
-           controller for the menu.
+        controller for the menu.
         """
         self._menu_context = {
             "selection": selection,
@@ -458,20 +447,17 @@ class BaseTableEditor(object):
     # -------------------------------------------------------------------------
 
     def add_to_menu(self, menu_item):
-        """ Adds a menu item to the menu bar being constructed.
-        """
+        """Adds a menu item to the menu bar being constructed."""
         action = menu_item.item.action
         self.eval_when(action.enabled_when, menu_item, "enabled")
         self.eval_when(action.checked_when, menu_item, "checked")
 
     def add_to_toolbar(self, toolbar_item):
-        """ Adds a toolbar item to the toolbar being constructed.
-        """
+        """Adds a toolbar item to the toolbar being constructed."""
         self.add_to_menu(toolbar_item)
 
     def can_add_to_menu(self, action):
-        """ Returns whether the action should be defined in the user interface.
-        """
+        """Returns whether the action should be defined in the user interface."""
         if action.defined_when != "":
             if not eval(action.defined_when, globals(), self._menu_context):
                 return False
@@ -483,14 +469,13 @@ class BaseTableEditor(object):
         return True
 
     def can_add_to_toolbar(self, action):
-        """ Returns whether the toolbar action should be defined in the user
-            interface.
+        """Returns whether the toolbar action should be defined in the user
+        interface.
         """
         return self.can_add_to_menu(action)
 
     def perform(self, action, action_event=None):
-        """ Performs the action described by a specified Action object.
-        """
+        """Performs the action described by a specified Action object."""
         self.ui.do_undoable(self._perform, action)
 
     def _perform(self, action):
@@ -527,7 +512,7 @@ class BaseTableEditor(object):
     # -------------------------------------------------------------------------
 
     def eval_when(self, condition, object, trait):
-        """ Evaluates a condition within a defined context and sets a specified
+        """Evaluates a condition within a defined context and sets a specified
         object trait based on the result, which is assumed to be a Boolean.
         """
         if condition != "":
@@ -541,20 +526,18 @@ class BaseTableEditor(object):
 
 
 class ReversedList(object):
-    """ A list whose order is the reverse of its input.
-    """
+    """A list whose order is the reverse of its input."""
 
     def __init__(self, list):
         self.list = list
 
     def insert(self, index, value):
-        """ Inserts a value at a specified index in the list.
-        """
+        """Inserts a value at a specified index in the list."""
         return self.list.insert(self._index(index - 1), value)
 
     def index(self, value):
-        """ Returns the index of the first occurrence of the specified value in
-            the list.
+        """Returns the index of the first occurrence of the specified value in
+        the list.
         """
         list = self.list[:]
         list.reverse()
@@ -562,28 +545,23 @@ class ReversedList(object):
         return list.index(value)
 
     def __len__(self):
-        """ Returns the length of the list.
-        """
+        """Returns the length of the list."""
         return len(self.list)
 
     def __getitem__(self, index):
-        """ Returns the value at a specified index in the list.
-        """
+        """Returns the value at a specified index in the list."""
         return self.list[self._index(index)]
 
     def __setslice__(self, i, j, values):
-        """ Sets a slice of a list to the contents of a specified sequence.
-        """
+        """Sets a slice of a list to the contents of a specified sequence."""
         return self.list.__setslice__(self._index(i), self._index(j), values)
 
     def __delitem__(self, index):
-        """ Deletes the item at a specified index.
-        """
+        """Deletes the item at a specified index."""
         return self.list.__delitem__(self._index(index))
 
     def _index(self, index):
-        """ Returns the "reversed" value for a specified index.
-        """
+        """Returns the "reversed" value for a specified index."""
         if index < 0:
             return -1 - index
 
