@@ -1,37 +1,28 @@
-# -------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2007, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   05/20/2007
-#
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ A traits UI editor for editing tabular data (arrays, list of tuples, lists
     of objects, etc).
 """
 
-
+import warnings
 
 from pyface.ui_traits import Image
 from traits.api import Str, Bool, Property, List, Enum, Instance
 
-from ..basic_editor_factory import BasicEditorFactory
-
-from ..toolkit import toolkit_object
+from traitsui.basic_editor_factory import BasicEditorFactory
+from traitsui.toolkit import toolkit_object
 
 
 class TabularEditor(BasicEditorFactory):
-    """ Editor factory for tabular editors.
-    """
+    """Editor factory for tabular editors."""
 
     # -- Trait Definitions ----------------------------------------------------
 
@@ -53,25 +44,26 @@ class TabularEditor(BasicEditorFactory):
     refresh = Str()
 
     #: Should the table update automatically when the table item's contents
-    #: change? Note that in order for this feature to work correctly, the editor
-    #: trait should be a list of objects derived from HasTraits. Also,
-    #: performance can be affected when very long lists are used, since enabling
-    #: this feature adds and removed Traits listeners to each item in the list.
+    #: change? Note that in order for this feature to work correctly, the
+    #: editor trait should be a list of objects derived from HasTraits. Also,
+    #: performance can be affected when very long lists are used, since
+    #: enabling this feature adds and removed Traits listeners to each item in
+    #: the list.
     auto_update = Bool(False)
 
     #: The optional extended name of the trait to synchronize the selection
     #: values with:
     selected = Str()
 
-    #: The optional extended name of the trait to synchronize the selection rows
-    #: with:
+    #: The optional extended name of the trait to synchronize the selection
+    #: rows with:
     selected_row = Str()
 
     #: Whether or not to allow selection.
     selectable = Bool(True)
 
-    #: The optional extended name of the trait to synchronize the activated value
-    #: with:
+    #: The optional extended name of the trait to synchronize the activated
+    #: value with:
     activated = Str()
 
     #: The optional extended name of the trait to synchronize the activated
@@ -110,8 +102,12 @@ class TabularEditor(BasicEditorFactory):
     #: trigger a scroll-to command. The data is an integer giving the column.
     scroll_to_column = Str()
 
-    #: Controls behavior of scroll to row
-    scroll_to_row_hint = Enum("center", "top", "bottom", "visible")
+    #: Deprecated: Controls behavior of scroll to row and scroll to column
+    scroll_to_row_hint = Property(Str, observe="scroll_to_position_hint")
+
+    #: (replacement of scroll_to_row_hint, but more clearly named)
+    #: Controls behavior of scroll to row and scroll to column
+    scroll_to_position_hint = Enum("visible", "center", "top", "bottom")
 
     #: Can the user edit the values?
     editable = Bool(True)
@@ -128,8 +124,8 @@ class TabularEditor(BasicEditorFactory):
     #: Should vertical lines be drawn between items?
     vertical_lines = Bool(True)
 
-    #: Should the columns automatically resize? Don't allow this when the amount
-    #: of data is large.
+    #: Should the columns automatically resize? Don't allow this when the
+    #: amount of data is large.
     auto_resize = Bool(False)
 
     #: Should the rows automatically resize (Qt4 only)? Don't allow
@@ -156,6 +152,21 @@ class TabularEditor(BasicEditorFactory):
     images = List(Image)
 
     def _get_klass(self):
-        """ Returns the toolkit-specific editor class to be instantiated.
-        """
+        """Returns the toolkit-specific editor class to be instantiated."""
         return toolkit_object("tabular_editor:TabularEditor")
+
+    def _get_scroll_to_row_hint(self):
+        warnings.warn(
+            "Use of scroll_to_row_hint trait is deprecated. "
+            "Use scroll_to_position_hint instead.",
+            DeprecationWarning,
+        )
+        return self.scroll_to_position_hint
+
+    def _set_scroll_to_row_hint(self, hint):
+        warnings.warn(
+            "Use of scroll_to_row_hint trait is deprecated. "
+            "Use scroll_to_position_hint instead.",
+            DeprecationWarning,
+        )
+        self.scroll_to_position_hint = hint
