@@ -1,3 +1,13 @@
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
@@ -25,8 +35,7 @@ from traits.api import HasTraits, Instance, Property
 
 
 class _Clipboard(HasTraits):
-    """ The _Clipboard class provides a wrapper around the PyQt clipboard.
-    """
+    """The _Clipboard class provides a wrapper around the PyQt clipboard."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -49,8 +58,7 @@ class _Clipboard(HasTraits):
     # -------------------------------------------------------------------------
 
     def _get_instance(self):
-        """ The instance getter.
-        """
+        """The instance getter."""
         md = PyMimeData.coerce(self.clipboard.mimeData())
         if md is None:
             return None
@@ -58,18 +66,15 @@ class _Clipboard(HasTraits):
         return md.instance()
 
     def _set_instance(self, data):
-        """ The instance setter.
-        """
+        """The instance setter."""
         self.clipboard.setMimeData(PyMimeData(data))
 
     def _get_has_instance(self):
-        """ The has_instance getter.
-        """
+        """The has_instance getter."""
         return self.clipboard.mimeData().hasFormat(PyMimeData.MIME_TYPE)
 
     def _get_instance_type(self):
-        """ The instance_type getter.
-        """
+        """The instance_type getter."""
         md = PyMimeData.coerce(self.clipboard.mimeData())
         if md is None:
             return None
@@ -81,8 +86,7 @@ class _Clipboard(HasTraits):
     # -------------------------------------------------------------------------
 
     def _clipboard_default(self):
-        """ Initialise the clipboard.
-        """
+        """Initialise the clipboard."""
         return QtGui.QApplication.clipboard()
 
 
