@@ -1,3 +1,13 @@
+# (C) Copyright 2009-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2008, Riverbank Computing Limited
 # All rights reserved.
@@ -17,33 +27,22 @@
 from functools import reduce
 
 
-
-from pyface.qt import QtCore, QtGui
+from pyface.qt import QtCore, QtGui, is_pyside
 
 from traits.api import Bool, Property
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.enum_editor file.
-from traitsui.editors.enum_editor import ToolkitEditorFactory
 from traitsui.helper import enum_values_changed
 from .constants import OKColor, ErrorColor
 from .editor import Editor
 
-
-# default formatting function (would import from string, but not in Python 3)
-capitalize = lambda s: s.capitalize()
-
-
 completion_mode_map = {
-    "popup": QtGui.QCompleter.PopupCompletion,
-    "inline": QtGui.QCompleter.InlineCompletion,
+    "popup": QtGui.QCompleter.CompletionMode.PopupCompletion,
+    "inline": QtGui.QCompleter.CompletionMode.InlineCompletion,
 }
 
 
 class BaseEditor(Editor):
-    """ Base class for enumeration editors.
-    """
+    """Base class for enumeration editors."""
 
     #: Current set of enumeration names:
     names = Property()
@@ -59,17 +58,20 @@ class BaseEditor(Editor):
     # -------------------------------------------------------------------------
 
     def values_changed(self):
-        """ Recomputes the cached data based on the underlying enumeration model.
+        """Recomputes the cached data based on the underlying enumeration model
+        or the values of the factory.
         """
-        self._names, self._mapping, self._inverse_mapping = enum_values_changed(
-            self._value(), self.string_value
-        )
+        (
+            self._names,
+            self._mapping,
+            self._inverse_mapping,
+        ) = enum_values_changed(self._value(), self.string_value)
 
     def rebuild_editor(self):
-        """ Rebuilds the contents of the editor whenever the original factory
-            object's **values** trait changes.
+        """Rebuilds the contents of the editor whenever the original factory
+        object's **values** trait changes.
 
-            This is not needed for the Qt backends.
+        This is not needed for the Qt backends.
         """
         raise NotImplementedError
 
@@ -78,8 +80,8 @@ class BaseEditor(Editor):
     # -------------------------------------------------------------------------
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         factory = self.factory
         if factory.name != "":
@@ -87,27 +89,36 @@ class BaseEditor(Editor):
                 factory.name
             )
             self.values_changed()
-            self._object.on_trait_change(
-                self._values_changed, " " + self._name, dispatch="ui"
+            self._object.observe(
+                self._update_values_and_rebuild_editor,
+                self._name + '.items',
+                dispatch="ui",
             )
         else:
-            factory.on_trait_change(
-                self.rebuild_editor, "values_modified", dispatch="ui"
+            self._value = lambda: self.factory.values
+            self.values_changed()
+            factory.observe(
+                self._update_values_and_rebuild_editor, "values", dispatch="ui"
             )
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
         if self._object is not None:
-            self._object.on_trait_change(
-                self._values_changed, " " + self._name, remove=True
+            self._object.observe(
+                self._update_values_and_rebuild_editor,
+                self._name + '.items',
+                remove=True,
+                dispatch="ui",
             )
         else:
-            self.factory.on_trait_change(
-                self.rebuild_editor, "values_modified", remove=True
+            self.factory.observe(
+                self._update_values_and_rebuild_editor,
+                "values",
+                remove=True,
+                dispatch="ui",
             )
 
-        super(BaseEditor, self).dispose()
+        super().dispose()
 
     # -------------------------------------------------------------------------
     #  Private interface
@@ -116,56 +127,44 @@ class BaseEditor(Editor):
     # Trait default handlers -------------------------------------------------
 
     def _get_names(self):
-        """ Gets the current set of enumeration names.
-        """
-        if self._object is None:
-            return self.factory._names
-
+        """Gets the current set of enumeration names."""
         return self._names
 
     def _get_mapping(self):
-        """ Gets the current mapping.
-        """
-        if self._object is None:
-            return self.factory._mapping
-
+        """Gets the current mapping."""
         return self._mapping
 
     def _get_inverse_mapping(self):
-        """ Gets the current inverse mapping.
-        """
-        if self._object is None:
-            return self.factory._inverse_mapping
-
+        """Gets the current inverse mapping."""
         return self._inverse_mapping
 
     # Trait change handlers --------------------------------------------------
 
-    def _values_changed(self):
-        """ Handles the underlying object model's enumeration set being changed.
+    def _update_values_and_rebuild_editor(self, event):
+        """Handles the underlying object model's enumeration set or factory's
+        values being changed.
         """
         self.values_changed()
         self.rebuild_editor()
 
 
 class SimpleEditor(BaseEditor):
-    """ Simple style of enumeration editor, which displays a combo box.
-    """
+    """Simple style of enumeration editor, which displays a combo box."""
 
     # -------------------------------------------------------------------------
     #  Editor Interface
     # -------------------------------------------------------------------------
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
-        super(SimpleEditor, self).init(parent)
+        super().init(parent)
 
         self.control = control = self.create_combo_box()
-        control.addItems(self.names)
+        self._add_items_to_combo_box()
 
-        control.currentIndexChanged[str].connect(self.update_object)
+        control.currentIndexChanged.connect(self.update_object)
 
         if self.factory.evaluate is not None:
             control.setEditable(True)
@@ -178,14 +177,14 @@ class SimpleEditor(BaseEditor):
                 control.lineEdit().editingFinished.connect(
                     self.update_autoset_text_object
                 )
-            control.setInsertPolicy(QtGui.QComboBox.NoInsert)
+            control.setInsertPolicy(QtGui.QComboBox.InsertPolicy.NoInsert)
 
         self._no_enum_update = 0
         self.set_tooltip()
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         if self._no_enum_update == 0:
             self._no_enum_update += 1
@@ -203,33 +202,30 @@ class SimpleEditor(BaseEditor):
             self._no_enum_update -= 1
 
     def error(self, excp):
-        """ Handles an error that occurs while setting the object's trait value.
-        """
+        """Handles an error that occurs while setting the object's trait value."""
         self._set_background(ErrorColor)
 
     def rebuild_editor(self):
-        """ Rebuilds the contents of the editor whenever the original factory
-            object's **values** trait changes.
+        """Rebuilds the contents of the editor whenever the original factory
+        object's **values** trait changes.
         """
         self.control.blockSignals(True)
         try:
             self.control.clear()
-            self.control.addItems(self.names)
+            self._add_items_to_combo_box()
         finally:
             self.control.blockSignals(False)
 
         self.update_editor()
 
     def set_size_policy(self, direction, resizable, springy, stretch):
-        super(SimpleEditor, self).set_size_policy(
-            direction, resizable, springy, stretch
-        )
+        super().set_size_policy(direction, resizable, springy, stretch)
 
-        if (direction == QtGui.QBoxLayout.LeftToRight and springy) or (
-            direction != QtGui.QBoxLayout.LeftToRight and resizable
+        if (direction == QtGui.QBoxLayout.Direction.LeftToRight and springy) or (
+            direction != QtGui.QBoxLayout.Direction.LeftToRight and resizable
         ):
             self.control.setSizeAdjustPolicy(
-                QtGui.QComboBox.AdjustToContentsOnFirstShow
+                QtGui.QComboBox.SizeAdjustPolicy.AdjustToContentsOnFirstShow
             )
 
     # -------------------------------------------------------------------------
@@ -237,30 +233,36 @@ class SimpleEditor(BaseEditor):
     # -------------------------------------------------------------------------
 
     def create_combo_box(self):
-        """ Returns the QComboBox used for the editor control.
-        """
+        """Returns the QComboBox used for the editor control."""
         control = QtGui.QComboBox()
-        control.setSizeAdjustPolicy(QtGui.QComboBox.AdjustToContents)
+        control.setSizeAdjustPolicy(QtGui.QComboBox.SizeAdjustPolicy.AdjustToContents)
         control.setSizePolicy(
-            QtGui.QSizePolicy.Maximum, QtGui.QSizePolicy.Fixed
+            QtGui.QSizePolicy.Policy.Maximum, QtGui.QSizePolicy.Policy.Fixed
         )
         return control
 
+    def _add_items_to_combo_box(self):
+        for name in self.names:
+            if self.factory.use_separator and name == self.factory.separator:
+                self.control.insertSeparator(self.control.count())
+            else:
+                self.control.addItem(name)
+
     def _set_background(self, col):
         le = self.control.lineEdit()
         pal = QtGui.QPalette(le.palette())
-        pal.setColor(QtGui.QPalette.Base, col)
+        pal.setColor(QtGui.QPalette.ColorRole.Base, col)
         le.setPalette(pal)
 
     #  Signal handlers -------------------------------------------------------
 
-    def update_object(self, text):
-        """ Handles the user selecting a new value from the combo box.
-        """
+    def update_object(self, index):
+        """Handles the user selecting a new value from the combo box."""
         if self._no_enum_update == 0:
             self._no_enum_update += 1
             try:
-                self.value = self.mapping[str(text)]
+                text = self.names[index]
+                self.value = self.mapping[text]
             except Exception:
                 from traitsui.api import raise_to_debug
 
@@ -268,8 +270,7 @@ class SimpleEditor(BaseEditor):
             self._no_enum_update -= 1
 
     def update_text_object(self, text):
-        """ Handles the user typing text into the combo box text entry field.
-        """
+        """Handles the user typing text into the combo box text entry field."""
         if self._no_enum_update == 0:
 
             value = str(text)
@@ -300,8 +301,8 @@ class SimpleEditor(BaseEditor):
 
 
 class RadioEditor(BaseEditor):
-    """ Enumeration editor, used for the "custom" style, that displays radio
-        buttons.
+    """Enumeration editor, used for the "custom" style, that displays radio
+    buttons.
     """
 
     #: Is the button layout row-major or column-major?
@@ -312,23 +313,26 @@ class RadioEditor(BaseEditor):
     # -------------------------------------------------------------------------
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
-        super(RadioEditor, self).init(parent)
+        super().init(parent)
 
         self.control = QtGui.QWidget()
         layout = QtGui.QGridLayout(self.control)
         layout.setContentsMargins(0, 0, 0, 0)
 
         self._mapper = QtCore.QSignalMapper()
-        self._mapper.mapped.connect(self.update_object)
+        if is_pyside and QtCore.__version_info__ >= (5, 15):
+            self._mapper.mappedInt.connect(self.update_object)
+        else:
+            self._mapper.mapped.connect(self.update_object)
 
         self.rebuild_editor()
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         layout = self.control.layout()
         value = self.value
@@ -337,8 +341,8 @@ class RadioEditor(BaseEditor):
             rb.setChecked(rb.value == value)
 
     def rebuild_editor(self):
-        """ Rebuilds the contents of the editor whenever the original factory
-            object's **values** trait changes.
+        """Rebuilds the contents of the editor whenever the original factory
+        object's **values** trait changes.
         """
         # Clear any existing content:
         self.clear_layout()
@@ -352,6 +356,9 @@ class RadioEditor(BaseEditor):
         n = len(names)
         cols = self.factory.cols
         rows = (n + cols - 1) // cols
+        # incr will keep track of how to increment index so that as we traverse
+        # the grid in row major order, the elements are added to appear in
+        # the correct order
         if self.row_major:
             incr = [1] * cols
         else:
@@ -360,10 +367,15 @@ class RadioEditor(BaseEditor):
             for i in range(cols):
                 incr[i] += rem > i
             incr[-1] = -(reduce(lambda x, y: x + y, incr[:-1], 0) - 1)
+            # e.g for a gird:
+            # 0 2 4
+            # 1 3 5
+            # incr should be [2, 2, -3]
 
         # Add the set of all possible choices:
         layout = self.control.layout()
         index = 0
+        # populate the layout in row_major order
         for i in range(rows):
             for j in range(cols):
                 if n > 0:
@@ -373,7 +385,11 @@ class RadioEditor(BaseEditor):
 
                     rb.setChecked(name == cur_name)
 
-                    rb.clicked.connect(self._mapper.map)
+                    # The connection type is set to workaround Qt5 + MacOSX
+                    # issue with event dispatching. See enthought/traitsui#1308
+                    rb.clicked.connect(
+                        self._mapper.map, type=QtCore.Qt.ConnectionType.QueuedConnection
+                    )
                     self._mapper.setMapping(rb, index)
 
                     self.set_tooltip(rb)
@@ -387,16 +403,14 @@ class RadioEditor(BaseEditor):
     # -------------------------------------------------------------------------
 
     def create_button(self, name):
-        """ Returns the QAbstractButton used for the radio button.
-        """
-        label = self.string_value(name, capitalize)
+        """Returns the QAbstractButton used for the radio button."""
+        label = self.string_value(name, str.capitalize)
         return QtGui.QRadioButton(label)
 
     #  Signal handlers -------------------------------------------------------
 
     def update_object(self, index):
-        """ Handles the user clicking one of the custom radio buttons.
-        """
+        """Handles the user clicking one of the custom radio buttons."""
         try:
             self.value = self.mapping[self.names[index]]
         except Exception:
@@ -404,8 +418,8 @@ class RadioEditor(BaseEditor):
 
 
 class ListEditor(BaseEditor):
-    """ Enumeration editor, used for the "custom" style, that displays a list
-        box.
+    """Enumeration editor, used for the "custom" style, that displays a list
+    box.
     """
 
     # -------------------------------------------------------------------------
@@ -413,10 +427,10 @@ class ListEditor(BaseEditor):
     # -------------------------------------------------------------------------
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
-        super(ListEditor, self).init(parent)
+        super().init(parent)
 
         self.control = QtGui.QListWidget()
         self.control.currentTextChanged.connect(self.update_object)
@@ -425,8 +439,8 @@ class ListEditor(BaseEditor):
         self.set_tooltip()
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         control = self.control
         try:
@@ -443,8 +457,8 @@ class ListEditor(BaseEditor):
             pass
 
     def rebuild_editor(self):
-        """ Rebuilds the contents of the editor whenever the original factory
-            object's **values** trait changes.
+        """Rebuilds the contents of the editor whenever the original factory
+        object's **values** trait changes.
         """
 
         self.control.blockSignals(True)
@@ -462,8 +476,7 @@ class ListEditor(BaseEditor):
     #  Signal handlers -------------------------------------------------------
 
     def update_object(self, text):
-        """ Handles the user selecting a list box item.
-        """
+        """Handles the user selecting a list box item."""
         value = str(text)
         try:
             value = self.mapping[value]
