@@ -1,3 +1,13 @@
+# (C) Copyright 2009-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2008, Riverbank Computing Limited
 # All rights reserved.
@@ -18,11 +28,8 @@
 from pyface.qt import QtCore, QtGui
 
 from traits.api import HasTraits, Instance, Property
+from traits.observation.api import trait
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.instance_editor file.
-from traitsui.editors.instance_editor import ToolkitEditorFactory
 from traitsui.ui_traits import AView
 from traitsui.helper import user_name_for
 from traitsui.handler import Handler
@@ -35,13 +42,13 @@ from .helper import position_window
 
 OrientationMap = {
     "default": None,
-    "horizontal": QtGui.QBoxLayout.LeftToRight,
-    "vertical": QtGui.QBoxLayout.TopToBottom,
+    "horizontal": QtGui.QBoxLayout.Direction.LeftToRight,
+    "vertical": QtGui.QBoxLayout.Direction.TopToBottom,
 }
 
 
 class CustomEditor(Editor):
-    """ Custom style of editor for instances. If selection among instances is
+    """Custom style of editor for instances. If selection among instances is
     allowed, the editor displays a combo box listing instances that can be
     selected. If the current instance is editable, the editor displays a panel
     containing trait editors for all the instance's traits.
@@ -51,7 +58,7 @@ class CustomEditor(Editor):
     ok_color = DropColor
 
     #: The orientation of the instance editor relative to the instance selector:
-    orientation = QtGui.QBoxLayout.TopToBottom
+    orientation = QtGui.QBoxLayout.Direction.TopToBottom
 
     #: Class constant:
     extra = 0
@@ -67,8 +74,8 @@ class CustomEditor(Editor):
     view = AView
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         factory = self.factory
         if factory.name != "":
@@ -100,19 +107,11 @@ class CustomEditor(Editor):
             self.set_tooltip(self._choice)
 
             if factory.name != "":
-                self._object.on_trait_change(
-                    self.rebuild_items, self._name, dispatch="ui"
-                )
-                self._object.on_trait_change(
-                    self.rebuild_items, self._name + "_items", dispatch="ui"
+                self._object.observe(
+                    self.rebuild_items, self._name + ".items", dispatch="ui"
                 )
 
-            factory.on_trait_change(
-                self.rebuild_items, "values", dispatch="ui"
-            )
-            factory.on_trait_change(
-                self.rebuild_items, "values_items", dispatch="ui"
-            )
+            factory.observe(self.rebuild_items, "values.items", dispatch="ui")
 
             self.rebuild_items()
 
@@ -121,11 +120,6 @@ class CustomEditor(Editor):
             self._choice.setReadOnly(True)
             self.set_tooltip(self._choice)
 
-        if droppable:
-            # Install EventFilter on control to handle DND events.
-            drop_event_filter = _DropEventFilter(self.control)
-            self.control.installEventFilter(drop_event_filter)
-
         orientation = OrientationMap[factory.orientation]
         if orientation is None:
             orientation = self.orientation
@@ -135,10 +129,10 @@ class CustomEditor(Editor):
             layout.setContentsMargins(0, 0, 0, 0)
             layout.addWidget(self._choice)
 
-            if orientation == QtGui.QBoxLayout.TopToBottom:
+            if orientation == QtGui.QBoxLayout.Direction.TopToBottom:
                 hline = QtGui.QFrame()
-                hline.setFrameShape(QtGui.QFrame.HLine)
-                hline.setFrameShadow(QtGui.QFrame.Sunken)
+                hline.setFrameShape(QtGui.QFrame.Shape.HLine)
+                hline.setFrameShadow(QtGui.QFrame.Shadow.Sunken)
 
                 layout.addWidget(hline)
 
@@ -154,6 +148,11 @@ class CustomEditor(Editor):
             layout.setContentsMargins(0, 0, 0, 0)
             self.create_editor(parent, layout)
 
+        if droppable:
+            # Install EventFilter on control to handle DND events.
+            drop_event_filter = _DropEventFilter(self.control)
+            self.control.installEventFilter(drop_event_filter)
+
         # Synchronize the 'view' to use:
         # fixme: A normal assignment can cause a crash (for unknown reasons) in
         # some cases, so we make sure that no notifications are generated:
@@ -161,14 +160,12 @@ class CustomEditor(Editor):
         self.sync_value(factory.view_name, "view", "from")
 
     def create_editor(self, parent, layout):
-        """ Creates the editor control.
-        """
+        """Creates the editor control."""
         self._panel = QtGui.QWidget()
         layout.addWidget(self._panel)
 
     def _get_items(self):
-        """ Gets the current list of InstanceChoiceItem items.
-        """
+        """Gets the current list of InstanceChoiceItem items."""
         if self._items is not None:
             return self._items
 
@@ -183,15 +180,21 @@ class CustomEditor(Editor):
         for value in values:
             if not isinstance(value, InstanceChoiceItem):
                 value = adapter(object=value)
+            # rebuild_items when an item's name changes so it is reflected by
+            # combobox. This change was added to fix enthought/traitsui#1641
+            value.object.observe(
+                self.rebuild_items,
+                trait(value.name_trait, optional=True),
+                dispatch="ui",
+            )
             items.append(value)
 
         self._items = items
 
         return items
 
-    def rebuild_items(self):
-        """ Rebuilds the object selector list.
-        """
+    def rebuild_items(self, event=None):
+        """Rebuilds the object selector list."""
         # Clear the current cached values:
         self._items = None
 
@@ -210,15 +213,15 @@ class CustomEditor(Editor):
         if name >= 0:
             choice.setCurrentIndex(name)
         else:
-            # Otherwise, current value is no longer valid, try to discard it:
+            # Otherwise, current value is no longer valid, set combobox empty
             try:
                 self.value = None
+                choice.setCurrentIndex(-1)
             except:
                 pass
 
     def item_for(self, object):
-        """ Returns the InstanceChoiceItem for a specified object.
-        """
+        """Returns the InstanceChoiceItem for a specified object."""
         for item in self.items:
             if item.is_compatible(object):
                 return item
@@ -226,8 +229,7 @@ class CustomEditor(Editor):
         return None
 
     def view_for(self, object, item):
-        """ Returns the view to use for a specified object.
-        """
+        """Returns the view to use for a specified object."""
         view = ""
         if item is not None:
             view = item.get_view()
@@ -240,8 +242,7 @@ class CustomEditor(Editor):
         )
 
     def update_object(self, index):
-        """ Handles the user selecting a new value from the combo box.
-        """
+        """Handles the user selecting a new value from the combo box."""
         item = self.items[index]
         id_item = id(item)
         object = self._object_cache.get(id_item)
@@ -258,8 +259,8 @@ class CustomEditor(Editor):
         self.resynch_editor()
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         # Synchronize the editor contents:
         self.resynch_editor()
@@ -267,20 +268,26 @@ class CustomEditor(Editor):
         # Update the selector (if any):
         choice = self._choice
         item = self.item_for(self.value)
-        if (choice is not None) and (item is not None):
-            name = item.get_name(self.value)
-            if self._object_cache is not None:
-                idx = choice.findText(name)
-                if idx < 0:
-                    idx = choice.count()
-                    choice.addItem(name)
+        if choice is not None:
+            if item is not None:
+                name = item.get_name(self.value)
+                if self._object_cache is not None:
+                    idx = choice.findText(name)
+                    if idx < 0:
+                        idx = choice.count()
+                        choice.addItem(name)
 
-                choice.setCurrentIndex(idx)
+                    choice.setCurrentIndex(idx)
+                else:
+                    choice.setText(name)
             else:
-                choice.setText(name)
+                # choice can also be a QLineEdit in which case we just leave
+                # text as empty
+                if isinstance(choice, QtGui.QComboBox):
+                    choice.setCurrentIndex(-1)
 
     def resynch_editor(self):
-        """ Resynchronizes the contents of the editor when the object trait
+        """Resynchronizes the contents of the editor when the object trait
         changes externally to the editor.
         """
         panel = self._panel
@@ -335,8 +342,7 @@ class CustomEditor(Editor):
             layout.addWidget(control)
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
         # Make sure we aren't hanging on to any object refs:
         self._object_cache = None
 
@@ -344,46 +350,46 @@ class CustomEditor(Editor):
             self._ui.dispose()
 
         if self._choice is not None:
-            if self._object is not None:
-                self._object.on_trait_change(
-                    self.rebuild_items, self._name, remove=True
-                )
-                self._object.on_trait_change(
-                    self.rebuild_items, self._name + "_items", remove=True
+            # _choice can also be a QLineEdit in which case we never set up
+            # this observer.
+            if isinstance(self._choice, QtGui.QComboBox):
+                if self._object is not None:
+                    self._object.observe(
+                        self.rebuild_items,
+                        self._name + ".items",
+                        remove=True,
+                        dispatch="ui",
+                    )
+
+                self.factory.observe(
+                    self.rebuild_items,
+                    "values.items",
+                    remove=True,
+                    dispatch="ui",
                 )
 
-            self.factory.on_trait_change(
-                self.rebuild_items, "values", remove=True
-            )
-            self.factory.on_trait_change(
-                self.rebuild_items, "values_items", remove=True
-            )
-
-        super(CustomEditor, self).dispose()
+        super().dispose()
 
     def error(self, excp):
-        """ Handles an error that occurs while setting the object's trait value.
-        """
+        """Handles an error that occurs while setting the object's trait value."""
         pass
 
     def get_error_control(self):
-        """ Returns the editor's control for indicating error status.
-        """
+        """Returns the editor's control for indicating error status."""
         return self._choice or self.control
 
     # -- UI preference save/restore interface ---------------------------------
 
     def restore_prefs(self, prefs):
-        """ Restores any saved user preference information associated with the
-            editor.
+        """Restores any saved user preference information associated with the
+        editor.
         """
         ui = self._ui
         if (ui is not None) and (prefs.get("id") == ui.id):
             ui.set_prefs(prefs.get("prefs"))
 
     def save_prefs(self):
-        """ Returns any user preference information associated with the editor.
-        """
+        """Returns any user preference information associated with the editor."""
         ui = self._ui
         if (ui is not None) and (ui.id != ""):
             return {"id": ui.id, "prefs": ui.get_prefs()}
@@ -397,7 +403,7 @@ class CustomEditor(Editor):
 
 
 class SimpleEditor(CustomEditor):
-    """ Simple style of editor for instances, which displays a button. Clicking
+    """Simple style of editor for instances, which displays a button. Clicking
     the button displays a dialog box in which the instance can be edited.
     """
 
@@ -405,21 +411,21 @@ class SimpleEditor(CustomEditor):
     _dialog_ui = Instance("traitsui.ui.UI")
 
     #: Class constants:
-    orientation = QtGui.QBoxLayout.LeftToRight
+    orientation = QtGui.QBoxLayout.Direction.LeftToRight
     extra = 2
 
     def create_editor(self, parent, layout):
-        """ Creates the editor control (a button).
-        """
+        """Creates the editor control (a button)."""
         self._button = QtGui.QPushButton()
+        self._button.setAutoDefault(False)
         layout.addWidget(self._button)
         self._button.clicked.connect(self.edit_instance)
         # Make sure the editor is properly disposed if parent UI is closed
         self._button.destroyed.connect(self._parent_closed)
 
     def edit_instance(self):
-        """ Edit the contents of the object trait when the user clicks the
-            button.
+        """Edit the contents of the object trait when the user clicks the
+        button.
         """
         # Create the user interface:
         factory = self.factory
@@ -445,8 +451,8 @@ class SimpleEditor(CustomEditor):
             self._dialog_ui = None
 
     def resynch_editor(self):
-        """ Resynchronizes the contents of the editor when the object trait
-            changes externally to the editor.
+        """Resynchronizes the contents of the editor when the object trait
+        changes externally to the editor.
         """
         button = self._button
         if button is not None:
