@@ -1,3 +1,13 @@
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 from pyface.qt import QtCore, QtGui
 from pyface.qt.QtGui import QFont
 
@@ -9,7 +19,6 @@ from .date_editor import SimpleEditor
 from .date_editor import CustomEditor as DateCustomEditor
 
 
-
 class CustomEditor(DateCustomEditor):
 
     dates = Dict()
@@ -17,10 +26,7 @@ class CustomEditor(DateCustomEditor):
     styles = Dict()
 
     def init(self, parent):
-        self.control = QtGui.QCalendarWidget()
-
-        if not self.factory.allow_future:
-            self.control.setMaximumDate(QtCore.QDate.currentDate())
+        super().init(parent)
 
         if not self.factory.allow_past:
             self.control.setMinimumDate(QtCore.QDate.currentDate())
@@ -29,10 +35,6 @@ class CustomEditor(DateCustomEditor):
             self.sync_value(self.factory.dates_trait, "dates", "from")
             self.sync_value(self.factory.styles_trait, "styles", "from")
 
-        self.control.clicked.connect(self.update_object)
-
-        return
-
     def _dates_changed(self, old, new):
         # Someone changed out the entire dict.  The easiest, most robust
         # way to handle this is to reset the text formats of all the dates
@@ -91,13 +93,13 @@ class CustomEditor(DateCustomEditor):
     # ------------------------------------------------------------------------
 
     def _apply_style(self, style, dates):
-        """ **style** is a CellFormat, **dates** is a list of datetime.date """
+        """**style** is a CellFormat, **dates** is a list of datetime.date"""
         for dt in dates:
-            self.set_unselected_style(style, date)
+            self.set_unselected_style(style, dt)
         return
 
     def _apply_styles(self, style_dict, date_dict):
-        """ Applies the proper style out of style_dict to every (name,date_list)
+        """Applies the proper style out of style_dict to every (name,date_list)
         in date_dict.
         """
         if not style_dict or not date_dict:
@@ -113,4 +115,4 @@ class CustomEditor(DateCustomEditor):
     def _reset_formatting(self, dates):
         # Resets the text format on the given dates
         for dt in dates:
-            self.apply_unselected_style(date)
+            self.apply_unselected_style(dt)
