@@ -1,26 +1,18 @@
-# -------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2009, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Evan Patterson
-#  Date:   06/22/2009
-#
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the table model used by the tabular editor.
 """
 
 
-
-
+import logging
 
 from pyface.qt import QtCore, QtGui
 
@@ -30,22 +22,23 @@ from .clipboard import PyMimeData
 
 # Mapping for trait alignment values to qt4 alignment values:
 alignment_map = {
-    "left": QtCore.Qt.AlignLeft,
-    "right": QtCore.Qt.AlignRight,
-    "center": QtCore.Qt.AlignHCenter,
-    "justify": QtCore.Qt.AlignJustify,
+    "left": QtCore.Qt.AlignmentFlag.AlignLeft,
+    "right": QtCore.Qt.AlignmentFlag.AlignRight,
+    "center": QtCore.Qt.AlignmentFlag.AlignHCenter,
+    "justify": QtCore.Qt.AlignmentFlag.AlignJustify,
 }
 
 # MIME type for internal table drag/drop operations
 tabular_mime_type = "traits-ui-tabular-editor"
 
+logger = logging.getLogger(__name__)
+
 
 class TabularModel(QtCore.QAbstractTableModel):
-    """ The model for tabular data."""
+    """The model for tabular data."""
 
     def __init__(self, editor, parent=None):
-        """ Initialise the object.
-        """
+        """Initialise the object."""
         QtCore.QAbstractTableModel.__init__(self, parent)
 
         self._editor = editor
@@ -55,39 +48,38 @@ class TabularModel(QtCore.QAbstractTableModel):
     # -------------------------------------------------------------------------
 
     def data(self, mi, role):
-        """ Reimplemented to return the data.
-        """
+        """Reimplemented to return the data."""
         editor = self._editor
         adapter = editor.adapter
         obj, name = editor.object, editor.name
         row, column = mi.row(), mi.column()
 
-        if role == QtCore.Qt.DisplayRole or role == QtCore.Qt.EditRole:
+        if role == QtCore.Qt.ItemDataRole.DisplayRole or role == QtCore.Qt.ItemDataRole.EditRole:
             return adapter.get_text(obj, name, row, column)
 
-        elif role == QtCore.Qt.DecorationRole:
+        elif role == QtCore.Qt.ItemDataRole.DecorationRole:
             image = editor._get_image(
                 adapter.get_image(obj, name, row, column)
             )
             if image is not None:
                 return image
 
-        elif role == QtCore.Qt.ToolTipRole:
+        elif role == QtCore.Qt.ItemDataRole.ToolTipRole:
             tooltip = adapter.get_tooltip(obj, name, row, column)
             if tooltip:
                 return tooltip
 
-        elif role == QtCore.Qt.FontRole:
+        elif role == QtCore.Qt.ItemDataRole.FontRole:
             font = adapter.get_font(obj, name, row, column)
             if font is not None:
                 return QtGui.QFont(font)
 
-        elif role == QtCore.Qt.TextAlignmentRole:
+        elif role == QtCore.Qt.ItemDataRole.TextAlignmentRole:
             string = adapter.get_alignment(obj, name, column)
-            alignment = alignment_map.get(string, QtCore.Qt.AlignLeft)
-            return int(alignment | QtCore.Qt.AlignVCenter)
+            alignment = alignment_map.get(string, QtCore.Qt.AlignmentFlag.AlignLeft)
+            return int(alignment | QtCore.Qt.AlignmentFlag.AlignVCenter)
 
-        elif role == QtCore.Qt.BackgroundRole:
+        elif role == QtCore.Qt.ItemDataRole.BackgroundRole:
             color = adapter.get_bg_color(obj, name, row, column)
             if color is not None:
                 if isinstance(color, SequenceTypes):
@@ -96,7 +88,7 @@ class TabularModel(QtCore.QAbstractTableModel):
                     q_color = QtGui.QColor(color)
                 return QtGui.QBrush(q_color)
 
-        elif role == QtCore.Qt.ForegroundRole:
+        elif role == QtCore.Qt.ItemDataRole.ForegroundRole:
             color = adapter.get_text_color(obj, name, row, column)
             if color is not None:
                 if isinstance(color, SequenceTypes):
@@ -108,9 +100,8 @@ class TabularModel(QtCore.QAbstractTableModel):
         return None
 
     def setData(self, mi, value, role):
-        """ Reimplmented to allow for modification for the object trait.
-        """
-        if role != QtCore.Qt.EditRole:
+        """Reimplmented to allow for modification for the object trait."""
+        if role != QtCore.Qt.ItemDataRole.EditRole:
             return False
 
         editor = self._editor
@@ -122,18 +113,17 @@ class TabularModel(QtCore.QAbstractTableModel):
         return True
 
     def flags(self, mi):
-        """ Reimplemented to set editable status and movable status.
-        """
+        """Reimplemented to set editable status and movable status."""
         editor = self._editor
         row = mi.row()
         column = mi.column()
 
         if not mi.isValid():
-            return QtCore.Qt.ItemIsDropEnabled
+            return QtCore.Qt.ItemFlag.ItemIsDropEnabled
 
-        flags = QtCore.Qt.ItemIsEnabled
+        flags = QtCore.Qt.ItemFlag.ItemIsEnabled
         if editor.factory.selectable:
-            flags |= QtCore.Qt.ItemIsSelectable
+            flags |= QtCore.Qt.ItemFlag.ItemIsSelectable
 
         # If the adapter defines get_can_edit_cell(), use it to determine
         # editability over the row-wise get_can_edit().
@@ -145,56 +135,53 @@ class TabularModel(QtCore.QAbstractTableModel):
             if editor.adapter.get_can_edit_cell(
                 editor.object, editor.name, row, column
             ):
-                flags |= QtCore.Qt.ItemIsEditable
+                flags |= QtCore.Qt.ItemFlag.ItemIsEditable
         elif (
             editor.factory.editable
             and "edit" in editor.factory.operations
             and editor.adapter.get_can_edit(editor.object, editor.name, row)
         ):
-            flags |= QtCore.Qt.ItemIsEditable
+            flags |= QtCore.Qt.ItemFlag.ItemIsEditable
 
         if (
             editor.adapter.get_drag(editor.object, editor.name, row)
             is not None
         ):
-            flags |= QtCore.Qt.ItemIsDragEnabled
+            flags |= QtCore.Qt.ItemFlag.ItemIsDragEnabled
 
         if editor.factory.editable:
-            flags |= QtCore.Qt.ItemIsDropEnabled
+            flags |= QtCore.Qt.ItemFlag.ItemIsDropEnabled
 
         return flags
 
     def headerData(self, section, orientation, role):
-        """ Reimplemented to return the header data.
-        """
-        if role != QtCore.Qt.DisplayRole:
+        """Reimplemented to return the header data."""
+        if role != QtCore.Qt.ItemDataRole.DisplayRole:
             return None
 
         editor = self._editor
 
         label = None
-        if orientation == QtCore.Qt.Vertical:
+        if orientation == QtCore.Qt.Orientation.Vertical:
             label = editor.adapter.get_row_label(section, editor.object)
-        elif orientation == QtCore.Qt.Horizontal:
+        elif orientation == QtCore.Qt.Orientation.Horizontal:
             label = editor.adapter.get_label(section, editor.object)
 
         return label
 
     def rowCount(self, mi):
-        """ Reimplemented to return the number of rows.
-        """
+        """Reimplemented to return the number of rows."""
         editor = self._editor
         return editor.adapter.len(editor.object, editor.name)
 
     def columnCount(self, mi):
-        """ Reimplemented to return the number of columns.
-        """
+        """Reimplemented to return the number of columns."""
         editor = self._editor
         return len(editor.adapter.columns)
 
     def insertRow(self, row, parent=QtCore.QModelIndex(), obj=None):
-        """ Reimplemented to allow creation of new rows. Added an optional
-            arg to allow the insertion of an existing row object.
+        """Reimplemented to allow creation of new rows. Added an optional
+        arg to allow the insertion of an existing row object.
         """
         editor = self._editor
         adapter = editor.adapter
@@ -209,8 +196,7 @@ class TabularModel(QtCore.QAbstractTableModel):
         return True
 
     def insertRows(self, row, count, parent=QtCore.QModelIndex()):
-        """ Reimplemented to allow creation of new items.
-        """
+        """Reimplemented to allow creation of new items."""
         editor = self._editor
         adapter = editor.adapter
 
@@ -224,8 +210,8 @@ class TabularModel(QtCore.QAbstractTableModel):
         return True
 
     def removeRows(self, row, count, parent=QtCore.QModelIndex()):
-        """ Reimplemented to allow row deletion, as well as reordering via drag
-            and drop.
+        """Reimplemented to allow row deletion, as well as reordering via drag
+        and drop.
         """
         editor = self._editor
         adapter = editor.adapter
@@ -242,8 +228,8 @@ class TabularModel(QtCore.QAbstractTableModel):
         return True
 
     def mimeTypes(self):
-        """ Reimplemented to expose our internal MIME type for drag and drop
-            operations.
+        """Reimplemented to expose our internal MIME type for drag and drop
+        operations.
         """
         return [
             tabular_mime_type,
@@ -252,8 +238,8 @@ class TabularModel(QtCore.QAbstractTableModel):
         ]
 
     def mimeData(self, indexes):
-        """ Reimplemented to generate MIME data containing the rows of the
-            current selection.
+        """Reimplemented to generate MIME data containing the rows of the
+        current selection.
         """
         rows = sorted({index.row() for index in indexes})
         items = [
@@ -270,14 +256,22 @@ class TabularModel(QtCore.QAbstractTableModel):
         return mime_data
 
     def dropMimeData(self, mime_data, action, row, column, parent):
-        """ Reimplemented to allow items to be moved.
-        """
-        if action == QtCore.Qt.IgnoreAction:
+        """Reimplemented to allow items to be moved."""
+        if action == QtCore.Qt.DropAction.IgnoreAction:
             return False
 
+        # If dropped directly onto the parent, both row and column are -1.
+        # See https://doc.qt.io/qt-5/qabstractitemmodel.html#dropMimeData
+        # When dropped below the list, the "parent" is invalid.
+        if row == -1:
+            if parent.isValid():
+                row = parent.row()
+            else:
+                row = max(0, self.rowCount(None) - 1)
+
         # this is a drag from a tabular model
         data = mime_data.data(tabular_mime_type)
-        if not data.isNull() and action == QtCore.Qt.MoveAction:
+        if not data.isNull() and action == QtCore.Qt.DropAction.MoveAction:
             id_and_rows = [
                 int(s) for s in data.data().decode("utf8").split(" ")
             ]
@@ -285,7 +279,7 @@ class TabularModel(QtCore.QAbstractTableModel):
             # is it from ourself?
             if table_id == id(self):
                 current_rows = id_and_rows[1:]
-                self.moveRows(current_rows, parent.row())
+                self.moveRows(current_rows, row)
                 return True
 
         # this is an external drag
@@ -297,12 +291,6 @@ class TabularModel(QtCore.QAbstractTableModel):
             object = editor.object
             name = editor.name
             adapter = editor.adapter
-            if row == -1 and parent.isValid():
-                # find correct row number
-                row = parent.row()
-            if row == -1 and adapter.len(object, name) == 0:
-                # if empty list, target is after end of list
-                row = 0
             if all(
                 adapter.get_can_drop(object, name, row, item) for item in data
             ):
@@ -312,16 +300,15 @@ class TabularModel(QtCore.QAbstractTableModel):
         return False
 
     def supportedDropActions(self):
-        """ Reimplemented to allow items to be moved.
-        """
-        return QtCore.Qt.MoveAction | QtCore.Qt.CopyAction
+        """Reimplemented to allow items to be moved."""
+        return QtCore.Qt.DropAction.MoveAction | QtCore.Qt.DropAction.CopyAction
 
     # -------------------------------------------------------------------------
     #  TabularModel interface:
     # -------------------------------------------------------------------------
 
     def dropItem(self, item, row):
-        """ Handle a Python object being dropped onto a row """
+        """Handle a Python object being dropped onto a row"""
         editor = self._editor
         object = editor.object
         name = editor.name
@@ -334,16 +321,24 @@ class TabularModel(QtCore.QAbstractTableModel):
         adapter.insert(object, name, row, item)
 
     def moveRow(self, old_row, new_row):
-        """ Convenience method to move a single row.
-        """
+        """Convenience method to move a single row."""
         return self.moveRows([old_row], new_row)
 
     def moveRows(self, current_rows, new_row):
-        """ Moves a sequence of rows (provided as a list of row indexes) to a
-            new row.
+        """Moves a sequence of rows (provided as a list of row indexes) to a
+        new row.
         """
         editor = self._editor
 
+        if new_row == -1:
+            # row should be nonnegative and less than the row count for this
+            # model. See ``QAbstractItemModel.checkIndex``` for Qt 5.11+
+            # This is a last resort to prevent segmentation faults.
+            logger.debug(
+                "Received invalid row %d. Adjusting to the last row.", new_row
+            )
+            new_row = max(0, self.rowCount(None) - 1)
+
         # Sort rows in descending order so they can be removed without
         # invalidating the indices.
         current_rows.sort()
