@@ -1,4 +1,4 @@
-# (C) Copyright 2008-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -24,9 +24,9 @@
 """
 
 
-
 import copy
 import collections.abc
+from functools import partial
 from itertools import zip_longest
 import logging
 
@@ -60,7 +60,6 @@ from .helper import pixmap_cache
 from .tree_node_renderers import WordWrapRenderer
 
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -69,8 +68,7 @@ DEFAULT_WRAP_RENDERER = WordWrapRenderer()
 
 
 class SimpleEditor(Editor):
-    """ Simple style of tree editor.
-    """
+    """Simple style of tree editor."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -102,8 +100,8 @@ class SimpleEditor(Editor):
     refresh = Event()
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         factory = self.factory
 
@@ -124,7 +122,7 @@ class SimpleEditor(Editor):
 
                     # Create the trait editor panel:
                     self.control = sa = QtGui.QScrollArea()
-                    sa.setFrameShape(QtGui.QFrame.NoFrame)
+                    sa.setFrameShape(QtGui.QFrame.Shape.NoFrame)
                     sa.setWidgetResizable(True)
                     self.control._node_ui = self.control._editor_nid = None
 
@@ -166,18 +164,18 @@ class SimpleEditor(Editor):
                 self._tree = _TreeWidget(self)
 
                 self._editor = sa = QtGui.QScrollArea()
-                sa.setFrameShape(QtGui.QFrame.NoFrame)
+                sa.setFrameShape(QtGui.QFrame.Shape.NoFrame)
                 sa.setWidgetResizable(True)
                 sa._node_ui = sa._editor_nid = None
 
                 if factory.orientation == "horizontal":
-                    orient = QtCore.Qt.Horizontal
+                    orient = QtCore.Qt.Orientation.Horizontal
                 else:
-                    orient = QtCore.Qt.Vertical
+                    orient = QtCore.Qt.Orientation.Vertical
 
                 self.control = splitter = QtGui.QSplitter(orient)
                 splitter.setSizePolicy(
-                    QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding
+                    QtGui.QSizePolicy.Policy.Expanding, QtGui.QSizePolicy.Policy.Expanding
                 )
                 splitter.addWidget(self._tree)
                 splitter.addWidget(sa)
@@ -207,8 +205,7 @@ class SimpleEditor(Editor):
         self.sync_value(factory.veto, "veto", "from")
 
     def _selection_changed(self, selection):
-        """ Handles the **selection** event.
-        """
+        """Handles the **selection** event."""
         try:
             tree = self._tree
             if not isinstance(selection, str) and isinstance(
@@ -222,7 +219,7 @@ class SimpleEditor(Editor):
                     item_selection.append(QtGui.QItemSelectionRange(idx))
 
                 tree.selectionModel().select(
-                    item_selection, QtGui.QItemSelectionModel.ClearAndSelect
+                    item_selection, QtGui.QItemSelectionModel.SelectionFlag.ClearAndSelect
                 )
             else:
                 tree.setCurrentItem(self._object_info(selection)[2])
@@ -232,24 +229,20 @@ class SimpleEditor(Editor):
             raise_to_debug()
 
     def _selected_changed(self, selected):
-        """ Handles the **selected** trait being changed.
-        """
+        """Handles the **selected** trait being changed."""
         if not self._no_update_selected:
             self._selection_changed(selected)
 
     def _veto_changed(self):
-        """ Handles the 'veto' event being fired.
-        """
+        """Handles the 'veto' event being fired."""
         self._veto = True
 
     def _refresh_changed(self):
-        """ Update the viewport.
-        """
+        """Update the viewport."""
         self._tree.viewport().update()
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
         if self._tree is not None:
             # Stop the chatter (specifically about the changing selection).
             self._tree.blockSignals(True)
@@ -261,8 +254,7 @@ class SimpleEditor(Editor):
         super().dispose()
 
     def expand_levels(self, nid, levels, expand=True):
-        """ Expands from the specified node the specified number of sub-levels.
-        """
+        """Expands from the specified node the specified number of sub-levels."""
         if levels > 0:
             expanded, node, object = self._get_node_data(nid)
             if self._has_children(node, object):
@@ -272,9 +264,26 @@ class SimpleEditor(Editor):
                 for cnid in self._nodes_for(nid):
                     self.expand_levels(cnid, levels - 1)
 
+    def expand_all(self):
+        """Expands all expandable nodes in the tree.
+
+        Warning: If the Tree contains a large number of items, this function
+        will be very slow.
+        """
+        # For more info on the QtGui.QTreeWidgetItemIterator object,
+        # see https://doc.qt.io/qt-5/qtreewidgetitemiterator.html
+        iterator = QtGui.QTreeWidgetItemIterator(self._tree)
+        while iterator.value():
+            item = iterator.value()
+            expanded, node, object = self._get_node_data(item)
+            if self._has_children(node, object):
+                self._expand_node(item)
+                item.setExpanded(True)
+            iterator += 1
+
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         tree = self._tree
         if tree is None:
@@ -318,8 +327,7 @@ class SimpleEditor(Editor):
         # FIXME: Clear the current editor (if any)...
 
     def get_error_control(self):
-        """ Returns the editor's control for indicating error status.
-        """
+        """Returns the editor's control for indicating error status."""
         return self._tree
 
     def _get_brush(self, color):
@@ -330,7 +338,7 @@ class SimpleEditor(Editor):
         return QtGui.QBrush(q_color)
 
     def _set_column_labels(self, nid, node, object):
-        """ Set the column labels. """
+        """Set the column labels."""
         column_labels = node.get_column_labels(object)
 
         for i, (header, label) in enumerate(
@@ -344,10 +352,10 @@ class SimpleEditor(Editor):
                 nid.setText(i, label)
 
     def _create_item(self, nid, node, object, index=None):
-        """ Create  a new TreeWidgetItem as per word_wrap policy.
+        """Create  a new TreeWidgetItem as per word_wrap policy.
 
         Index is the index of the new node in the parent:
-            None implies append the child to the end. """
+            None implies append the child to the end."""
         if index is None:
             cnid = QtGui.QTreeWidgetItem(nid)
         else:
@@ -375,7 +383,7 @@ class SimpleEditor(Editor):
         return cnid
 
     def _set_label(self, nid, col=0):
-        """ Set the label of the specified item """
+        """Set the label of the specified item"""
         if col != 0:
             # these are handled by _set_column_labels
             return
@@ -388,13 +396,12 @@ class SimpleEditor(Editor):
             nid.setText(col, node.get_label(object))
 
     def _append_node(self, nid, node, object):
-        """ Appends a new node to the specified node.
-        """
+        """Appends a new node to the specified node."""
         return self._insert_node(nid, None, node, object)
 
     def _insert_node(self, nid, index, node, object):
-        """ Inserts a new node before a specified index into the children of the
-            specified node.
+        """Inserts a new node before a specified index into the children of the
+        specified node.
         """
 
         cnid = self._create_item(nid, node, object, index)
@@ -421,8 +428,7 @@ class SimpleEditor(Editor):
         return cnid
 
     def _delete_node(self, nid):
-        """ Deletes a specified tree node and all its children.
-        """
+        """Deletes a specified tree node and all its children."""
 
         for cnid in self._nodes_for(nid):
             self._delete_node(cnid)
@@ -465,8 +471,7 @@ class SimpleEditor(Editor):
             self._clear_editor()
 
     def _expand_node(self, nid):
-        """ Expands the contents of a specified node (if required).
-        """
+        """Expands the contents of a specified node (if required)."""
         expanded, node, object = self._get_node_data(nid)
 
         # Lazily populate the item's children:
@@ -486,8 +491,7 @@ class SimpleEditor(Editor):
             self._set_node_data(nid, (True, node, object))
 
     def _nodes_for(self, nid):
-        """ Returns all child node ids of a specified node id.
-        """
+        """Returns all child node ids of a specified node id."""
         return [nid.child(i) for i in range(nid.childCount())]
 
     def _node_index(self, nid):
@@ -507,8 +511,7 @@ class SimpleEditor(Editor):
             return (None, None, None)
 
     def _has_children(self, node, object):
-        """ Returns whether a specified object has any children.
-        """
+        """Returns whether a specified object has any children."""
         return node.allows_children(object) and node.has_children(object)
 
     # -------------------------------------------------------------------------
@@ -516,14 +519,13 @@ class SimpleEditor(Editor):
     # -------------------------------------------------------------------------
 
     STD_ICON_MAP = {
-        "<item>": QtGui.QStyle.SP_FileIcon,
-        "<group>": QtGui.QStyle.SP_DirClosedIcon,
-        "<open>": QtGui.QStyle.SP_DirOpenIcon,
+        "<item>": QtGui.QStyle.StandardPixmap.SP_FileIcon,
+        "<group>": QtGui.QStyle.StandardPixmap.SP_DirClosedIcon,
+        "<open>": QtGui.QStyle.StandardPixmap.SP_DirOpenIcon,
     }
 
     def _get_icon(self, node, object, is_expanded=False):
-        """ Returns the index of the specified object icon.
-        """
+        """Returns the index of the specified object icon."""
         if not self.factory.show_icons:
             return QtGui.QIcon()
 
@@ -570,14 +572,13 @@ class SimpleEditor(Editor):
         return QtGui.QIcon(pixmap_cache(file_name))
 
     def _icon_from_color(self, color):
-        """ Create a square icon filled with the given color. """
+        """Create a square icon filled with the given color."""
         pixmap = QtGui.QPixmap(self._tree.iconSize())
         pixmap.fill(color)
         return QtGui.QIcon(pixmap)
 
     def _add_listeners(self, node, object):
-        """ Adds the event listeners for a specified object.
-        """
+        """Adds the event listeners for a specified object."""
 
         if node.allows_children(object):
             node.when_children_replaced(object, self._children_replaced, False)
@@ -589,8 +590,7 @@ class SimpleEditor(Editor):
         )
 
     def _remove_listeners(self, node, object):
-        """ Removes any event listeners from a specified object.
-        """
+        """Removes any event listeners from a specified object."""
 
         if node.allows_children(object):
             node.when_children_replaced(object, self._children_replaced, True)
@@ -602,8 +602,8 @@ class SimpleEditor(Editor):
         )
 
     def _object_info(self, object, name=""):
-        """ Returns the tree node data for a specified object in the form
-            ( expanded, node, nid ).
+        """Returns the tree node data for a specified object in the form
+        ( expanded, node, nid ).
         """
         info = self._map[id(object)]
         for name2, nid in info:
@@ -617,8 +617,8 @@ class SimpleEditor(Editor):
         return (expanded, node, nid)
 
     def _object_info_for(self, object, name=""):
-        """ Returns the tree node data for a specified object as a list of the
-            form: [ ( expanded, node, nid ), ... ].
+        """Returns the tree node data for a specified object as a list of the
+        form: [ ( expanded, node, nid ), ... ].
         """
         result = []
         for name2, nid in self._map[id(object)]:
@@ -629,8 +629,7 @@ class SimpleEditor(Editor):
         return result
 
     def _node_for(self, object):
-        """ Returns the TreeNode associated with a specified object.
-        """
+        """Returns the TreeNode associated with a specified object."""
         if (
             (isinstance(object, tuple))
             and (len(object) == 2)
@@ -685,16 +684,14 @@ class SimpleEditor(Editor):
         return (object, multi_node)
 
     def _node_for_class(self, klass):
-        """ Returns the TreeNode associated with a specified class.
-        """
+        """Returns the TreeNode associated with a specified class."""
         for node in self.factory.nodes:
             if issubclass(klass, tuple(node.node_for)):
                 return node
         return None
 
     def _update_icon(self, nid):
-        """ Updates the icon for a specified node.
-        """
+        """Updates the icon for a specified node."""
         expanded, node, object = self._get_node_data(nid)
         renderer = node.get_renderer(object)
         if renderer is None or not renderer.handles_icon:
@@ -703,8 +700,7 @@ class SimpleEditor(Editor):
             nid.setIcon(0, QtGui.QIcon())
 
     def _begin_undo(self):
-        """ Begins an "undoable" transaction.
-        """
+        """Begins an "undoable" transaction."""
         ui = self.ui
         self._undoable.append(ui._undoable)
         if (ui._undoable == -1) and (ui.history is not None):
@@ -724,8 +720,7 @@ class SimpleEditor(Editor):
         )
 
     def _undoable_append(self, node, object, data, make_copy=True):
-        """ Performs an undoable append operation.
-        """
+        """Performs an undoable append operation."""
         try:
             self._begin_undo()
             if make_copy:
@@ -735,8 +730,7 @@ class SimpleEditor(Editor):
             self._end_undo()
 
     def _undoable_insert(self, node, object, index, data, make_copy=True):
-        """ Performs an undoable insert operation.
-        """
+        """Performs an undoable insert operation."""
         try:
             self._begin_undo()
             if make_copy:
@@ -746,8 +740,7 @@ class SimpleEditor(Editor):
             self._end_undo()
 
     def _undoable_delete(self, node, object, index):
-        """ Performs an undoable delete operation.
-        """
+        """Performs an undoable delete operation."""
         try:
             self._begin_undo()
             node.delete_child(object, index)
@@ -755,8 +748,7 @@ class SimpleEditor(Editor):
             self._end_undo()
 
     def _get_object_nid(self, object, name=""):
-        """ Gets the ID associated with a specified object (if any).
-        """
+        """Gets the ID associated with a specified object (if any)."""
         info = self._map.get(id(object))
         if info is None:
             return None
@@ -767,8 +759,7 @@ class SimpleEditor(Editor):
             return info[0][1]
 
     def _clear_editor(self):
-        """ Clears the current editor pane (if any).
-        """
+        """Clears the current editor pane (if any)."""
         editor = self._editor
         if editor._node_ui is not None:
             editor.setWidget(None)
@@ -781,24 +772,23 @@ class SimpleEditor(Editor):
 
     @staticmethod
     def _get_node_data(nid):
-        """ Gets the node specific data. """
+        """Gets the node specific data."""
         return nid._py_data
 
     @staticmethod
     def _set_node_data(nid, data):
-        """ Sets the node specific data. """
+        """Sets the node specific data."""
         nid._py_data = data
 
     # ----- User callable methods: --------------------------------------------
 
     def get_object(self, nid):
-        """ Gets the object associated with a specified node.
-        """
+        """Gets the object associated with a specified node."""
         return self._get_node_data(nid)[2]
 
     def get_parent(self, object, name=""):
-        """ Returns the object that is the immmediate parent of a specified
-            object in the tree.
+        """Returns the object that is the immmediate parent of a specified
+        object in the tree.
         """
         nid = self._get_object_nid(object, name)
         if nid is not None:
@@ -808,8 +798,7 @@ class SimpleEditor(Editor):
         return None
 
     def get_node(self, object, name=""):
-        """ Returns the node associated with a specified object.
-        """
+        """Returns the node associated with a specified object."""
         nid = self._get_object_nid(object, name)
         if nid is not None:
             return self._get_node_data(nid)[1]
@@ -818,8 +807,7 @@ class SimpleEditor(Editor):
     # ----- Tree event handlers: ----------------------------------------------
 
     def _on_item_expanded(self, nid):
-        """ Handles a tree node being expanded.
-        """
+        """Handles a tree node being expanded."""
         expanded, node, object = self._get_node_data(nid)
 
         # If 'auto_close' requested for this node type, close all of the node's
@@ -839,13 +827,11 @@ class SimpleEditor(Editor):
         self._update_icon(nid)
 
     def _on_item_collapsed(self, nid):
-        """ Handles a tree node being collapsed.
-        """
+        """Handles a tree node being collapsed."""
         self._update_icon(nid)
 
     def _on_item_clicked(self, nid, col):
-        """ Handles a tree item being clicked.
-        """
+        """Handles a tree item being clicked."""
         _, node, object = self._get_node_data(nid)
 
         if node.click(object) is True and self.factory.on_click is not None:
@@ -855,8 +841,7 @@ class SimpleEditor(Editor):
         self.click = object
 
     def _on_item_dclicked(self, nid, col):
-        """ Handles a tree item being double-clicked.
-        """
+        """Handles a tree item being double-clicked."""
         _, node, object = self._get_node_data(nid)
 
         if node.dclick(object) is True:
@@ -870,8 +855,7 @@ class SimpleEditor(Editor):
         self.dclick = object
 
     def _on_item_activated(self, nid, col):
-        """ Handles a tree item being activated.
-        """
+        """Handles a tree item being activated."""
         _, node, object = self._get_node_data(nid)
 
         if node.activated(object) is True:
@@ -885,26 +869,25 @@ class SimpleEditor(Editor):
         self.activated = object
 
     def _on_tree_sel_changed(self):
-        """ Handles a tree node being selected.
-        """
+        """Handles a tree node being selected."""
         # Get the new selection:
         nids = self._tree.selectedItems()
 
         selected = []
+        first = True
         if len(nids) > 0:
+            selected = [self._get_node_data(nid)[2] for nid in nids]
             for nid in nids:
                 # If there is a real selection, get the associated object:
-                expanded, node, sel_object = self._get_node_data(nid)
-                selected.append(sel_object)
+                expanded, sel_node, sel_object = self._get_node_data(nid)
 
                 # Try to inform the node specific handler of the selection, if
                 # there are multiple selections, we only care about the first
-                # (or maybe the last makes more sense?)
-
-                # QTreeWidgetItem does not have an equal operator, so use id()
-                if id(nid) == id(nids[0]):
+                if first:
+                    node = sel_node
                     object = sel_object
                     not_handled = node.select(sel_object)
+                    first = False
         else:
             nid = None
             object = None
@@ -965,8 +948,7 @@ class SimpleEditor(Editor):
             editor.setUpdatesEnabled(True)
 
     def _on_context_menu(self, pos):
-        """ Handles the user requesting a context menuright clicking on a tree node.
-        """
+        """Handles the user requesting a context menuright clicking on a tree node."""
         nid = self._tree.itemAt(pos)
 
         if nid is None:
@@ -1027,8 +1009,7 @@ class SimpleEditor(Editor):
         ) = self._menu_parent_node = self._menu_parent_object = None
 
     def _standard_menu(self, node, object):
-        """ Returns the standard contextual pop-up menu.
-        """
+        """Returns the standard contextual pop-up menu."""
         actions = [
             CutAction,
             CopyAction,
@@ -1047,8 +1028,7 @@ class SimpleEditor(Editor):
         return Menu(*actions)
 
     def _new_actions(self, node, object):
-        """ Returns a list of Actions that will create new objects.
-        """
+        """Returns a list of Actions that will create new objects."""
         object = self._data[1]
         items = []
         add = node.get_add(object)
@@ -1073,9 +1053,12 @@ class SimpleEditor(Editor):
                 name = class_name
             if factory is None:
                 factory = klass
-            def perform_add(object):
+
+            def perform_add(object, factory, prompt):
                 self._menu_new_node(factory, prompt)
-            items.append(Action(name=name, on_perform=perform_add))
+
+            on_perform = partial(perform_add, factory=factory, prompt=prompt)
+            items.append(Action(name=name, on_perform=on_perform))
         return items
 
     # -------------------------------------------------------------------------
@@ -1126,24 +1109,22 @@ class SimpleEditor(Editor):
         nid = self._get_object_nid(object)
         flags = nid.flags()
         if can_rename:
-            flags |= QtCore.Qt.ItemIsEditable
+            flags |= QtCore.Qt.ItemFlag.ItemIsEditable
         else:
-            flags &= ~QtCore.Qt.ItemIsEditable
+            flags &= ~QtCore.Qt.ItemFlag.ItemIsEditable
         nid.setFlags(flags)
 
         return can_rename
 
     def _is_droppable(self, node, object, add_object, for_insert):
-        """ Returns whether a given object is droppable on the node.
-        """
+        """Returns whether a given object is droppable on the node."""
         if for_insert and (not node.can_insert(object)):
             return False
 
         return node.can_add(object, add_object)
 
     def _drop_object(self, node, object, dropped_object, make_copy=True):
-        """ Returns a droppable version of a specified object.
-        """
+        """Returns a droppable version of a specified object."""
         new_object = node.drop_object(object, dropped_object)
         if (new_object is not dropped_object) or (not make_copy):
             return new_object
@@ -1153,20 +1134,17 @@ class SimpleEditor(Editor):
     # ----- pyface.action 'controller' interface implementation: --------------
 
     def add_to_menu(self, menu_item):
-        """ Adds a menu item to the menu bar being constructed.
-        """
+        """Adds a menu item to the menu bar being constructed."""
         action = menu_item.item.action
         self.eval_when(action.enabled_when, menu_item, "enabled")
         self.eval_when(action.checked_when, menu_item, "checked")
 
     def add_to_toolbar(self, toolbar_item):
-        """ Adds a toolbar item to the toolbar being constructed.
-        """
+        """Adds a toolbar item to the toolbar being constructed."""
         self.add_to_menu(toolbar_item)
 
     def can_add_to_menu(self, action):
-        """ Returns whether the action should be defined in the user interface.
-        """
+        """Returns whether the action should be defined in the user interface."""
         if action.defined_when != "":
             if not eval(action.defined_when, globals(), self._context):
                 return False
@@ -1178,14 +1156,13 @@ class SimpleEditor(Editor):
         return True
 
     def can_add_to_toolbar(self, action):
-        """ Returns whether the toolbar action should be defined in the user
-            interface.
+        """Returns whether the toolbar action should be defined in the user
+        interface.
         """
         return self.can_add_to_menu(action)
 
     def perform(self, action, action_event=None):
-        """ Performs the action described by a specified Action object.
-        """
+        """Performs the action described by a specified Action object."""
         self.ui.do_undoable(self._perform, action)
 
     def _perform(self, action):
@@ -1226,7 +1203,7 @@ class SimpleEditor(Editor):
     # ----- Menu support methods: ---------------------------------------------
 
     def eval_when(self, condition, object, trait):
-        """ Evaluates a condition within a defined context, and sets a
+        """Evaluates a condition within a defined context, and sets a
         specified object trait based on the result, which is assumed to be a
         Boolean.
         """
@@ -1245,30 +1222,27 @@ class SimpleEditor(Editor):
     # ----- Menu event handlers: ----------------------------------------------
 
     def _menu_copy_node(self):
-        """ Copies the current tree node object to the paste buffer.
-        """
+        """Copies the current tree node object to the paste buffer."""
         clipboard.instance = self._data[1]
         self._data = None
 
     def _menu_cut_node(self):
-        """ Cuts the current tree node object into the paste buffer.
-        """
+        """Cuts the current tree node object into the paste buffer."""
         node, object, nid = self._data
         clipboard.instance = object
         self._data = None
         self._undoable_delete(*self._node_index(nid))
 
     def _menu_paste_node(self):
-        """ Pastes the current contents of the paste buffer into the current
-            node.
+        """Pastes the current contents of the paste buffer into the current
+        node.
         """
         node, object, nid = self._data
         self._data = None
         self._undoable_append(node, object, clipboard.instance, True)
 
     def _menu_delete_node(self):
-        """ Deletes the current node from the tree.
-        """
+        """Deletes the current node from the tree."""
         node, object, nid = self._data
         self._data = None
         rc = node.confirm_delete(object)
@@ -1281,23 +1255,21 @@ class SimpleEditor(Editor):
                         "Confirm Deletion",
                         "Are you sure you want to delete %s?"
                         % node.get_label(object),
-                        QtGui.QMessageBox.Yes | QtGui.QMessageBox.No,
+                        QtGui.QMessageBox.StandardButton.Yes | QtGui.QMessageBox.StandardButton.No,
                     )
-                    if butn != QtGui.QMessageBox.Yes:
+                    if butn != QtGui.QMessageBox.StandardButton.Yes:
                         return
 
             self._undoable_delete(*self._node_index(nid))
 
     def _menu_rename_node(self):
-        """ Rename the current node.
-        """
+        """Rename the current node."""
         _, _, nid = self._data
         self._data = None
         self._tree.editItem(nid)
 
     def _on_nid_changed(self, nid, col):
-        """ Handle changes to a widget item.
-        """
+        """Handle changes to a widget item."""
         # The node data may not have been set up for the nid yet.  Ignore it if
         # it hasn't.
         try:
@@ -1315,11 +1287,12 @@ class SimpleEditor(Editor):
                 self._set_label(nid, col)
 
     def _menu_new_node(self, factory, prompt=False):
-        """ Adds a new object to the current node.
-        """
+        """Adds a new object to the current node."""
         node, object, nid = self._data
         self._data = None
         new_object = factory()
+        if new_object is None:
+            return  # support None-type returns from factory
         if (not prompt) or new_object.edit_traits(
             parent=self.control, kind="livemodal"
         ).result:
@@ -1333,8 +1306,7 @@ class SimpleEditor(Editor):
     # ----- Model event handlers: ---------------------------------------------
 
     def _children_replaced(self, object, name="", new=None):
-        """ Handles the children of a node being completely replaced.
-        """
+        """Handles the children of a node being completely replaced."""
         tree = self._tree
         for expanded, node, nid in self._object_info_for(object, name):
             children = node.get_children(object)
@@ -1366,8 +1338,7 @@ class SimpleEditor(Editor):
                 nid.setExpanded(True)
 
     def _children_updated(self, object, name, event):
-        """ Handles the children of a node being changed.
-        """
+        """Handles the children of a node being changed."""
         # Log the change that was made made (removing '_items' from the end of
         # the name):
         name = name[:-6]
@@ -1422,8 +1393,7 @@ class SimpleEditor(Editor):
                 nid.setExpanded(True)
 
     def _label_updated(self, object, name, label):
-        """  Handles the label of an object being changed.
-        """
+        """Handles the label of an object being changed."""
         # Prevent the itemChanged() signal from being emitted.
         blk = self._tree.blockSignals(True)
         try:
@@ -1442,8 +1412,7 @@ class SimpleEditor(Editor):
             self._tree.blockSignals(blk)
 
     def _column_labels_updated(self, object, name, new):
-        """  Handles the column labels of an object being changed.
-        """
+        """Handles the column labels of an object being changed."""
         # Prevent the itemChanged() signal from being emitted.
         blk = self._tree.blockSignals(True)
         try:
@@ -1459,8 +1428,8 @@ class SimpleEditor(Editor):
     # -- UI preference save/restore interface ---------------------------------
 
     def restore_prefs(self, prefs):
-        """ Restores any saved user preference information associated with the
-            editor.
+        """Restores any saved user preference information associated with the
+        editor.
         """
         if isinstance(self.control, QtGui.QSplitter):
             if isinstance(prefs, dict):
@@ -1476,8 +1445,7 @@ class SimpleEditor(Editor):
             header.restoreState(prefs["column_state"])
 
     def save_prefs(self):
-        """ Returns any user preference information associated with the editor.
-        """
+        """Returns any user preference information associated with the editor."""
         prefs = {}
         if isinstance(self.control, QtGui.QSplitter):
             prefs["structure"] = self.control.saveState().data()
@@ -1492,17 +1460,16 @@ class SimpleEditor(Editor):
 
 
 class _TreeWidget(QtGui.QTreeWidget):
-    """ The _TreeWidget class is a specialised QTreeWidget that reimplements
-        the drag'n'drop support so that it hooks into the provided Traits
-        support.
+    """The _TreeWidget class is a specialised QTreeWidget that reimplements
+    the drag'n'drop support so that it hooks into the provided Traits
+    support.
     """
 
     def __init__(self, editor, parent=None):
-        """ Initialise the tree widget.
-        """
+        """Initialise the tree widget."""
         QtGui.QTreeWidget.__init__(self, parent)
 
-        self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.setContextMenuPolicy(QtCore.Qt.ContextMenuPolicy.CustomContextMenu)
         self.setDragEnabled(True)
         self.setAcceptDrops(True)
         self.setIconSize(QtCore.QSize(*editor.factory.icon_size))
@@ -1530,7 +1497,7 @@ class _TreeWidget(QtGui.QTreeWidget):
             )
 
         if editor.factory.selection_mode == "extended":
-            self.setSelectionMode(QtGui.QAbstractItemView.ExtendedSelection)
+            self.setSelectionMode(QtGui.QAbstractItemView.SelectionMode.ExtendedSelection)
 
         self.itemExpanded.connect(editor._on_item_expanded)
         self.itemCollapsed.connect(editor._on_item_collapsed)
@@ -1545,7 +1512,7 @@ class _TreeWidget(QtGui.QTreeWidget):
         self._dragging = None
 
     def resizeEvent(self, event):
-        """ Overridden to emit sizeHintChanged() of items for word wrapping """
+        """Overridden to emit sizeHintChanged() of items for word wrapping"""
         if self._editor.factory.word_wrap:
             for i in range(self.topLevelItemCount()):
                 mi = self.indexFromItem(self.topLevelItem(i))
@@ -1554,8 +1521,7 @@ class _TreeWidget(QtGui.QTreeWidget):
         super(self.__class__, self).resizeEvent(event)
 
     def startDrag(self, actions):
-        """ Reimplemented to start the drag of a tree widget item.
-        """
+        """Reimplemented to start the drag of a tree widget item."""
         nid = self.currentItem()
         if nid is None:
             return
@@ -1583,7 +1549,7 @@ class _TreeWidget(QtGui.QTreeWidget):
         painter = QtGui.QPainter(pm)
 
         option = self.viewOptions()
-        option.state |= QtGui.QStyle.State_Selected
+        option.state |= QtGui.QStyle.StateFlag.State_Selected
         option.rect = QtCore.QRect(
             nid_rect.topLeft() - rect.topLeft(), nid_rect.size()
         )
@@ -1599,8 +1565,8 @@ class _TreeWidget(QtGui.QTreeWidget):
         drag.exec_(actions)
 
     def dragEnterEvent(self, e):
-        """ Reimplemented to see if the current drag can be handled by the
-            tree.
+        """Reimplemented to see if the current drag can be handled by the
+        tree.
         """
         # Assume the drag is invalid.
         e.ignore()
@@ -1615,8 +1581,8 @@ class _TreeWidget(QtGui.QTreeWidget):
         e.acceptProposedAction()
 
     def dragMoveEvent(self, e):
-        """ Reimplemented to see if the current drag can be handled by the
-            particular tree widget item underneath the cursor.
+        """Reimplemented to see if the current drag can be handled by the
+        particular tree widget item underneath the cursor.
         """
         # Assume the drag is invalid.
         e.ignore()
@@ -1627,8 +1593,7 @@ class _TreeWidget(QtGui.QTreeWidget):
             e.acceptProposedAction()
 
     def dropEvent(self, e):
-        """ Reimplemented to update the model and tree.
-        """
+        """Reimplemented to update the model and tree."""
         # Assume the drop is invalid.
         e.ignore()
 
@@ -1690,8 +1655,7 @@ class _TreeWidget(QtGui.QTreeWidget):
         e.acceptProposedAction()
 
     def _get_action(self, event):
-        """ Work out what action on what object to perform for a drop event
-        """
+        """Work out what action on what object to perform for a drop event"""
         # default values to return
         action = None
         to_node = None
@@ -1721,8 +1685,9 @@ class _TreeWidget(QtGui.QTreeWidget):
         data = PyMimeData.coerce(event.mimeData()).instance()
         _, node, object = editor._get_node_data(nid)
 
-        if event.proposedAction() == QtCore.Qt.MoveAction and editor._is_droppable(
-            node, object, data, False
+        if (
+            event.proposedAction() == QtCore.Qt.DropAction.MoveAction
+            and editor._is_droppable(node, object, data, False)
         ):
             # append to node being dropped on
             action = "append"
@@ -1749,7 +1714,7 @@ class _TreeWidget(QtGui.QTreeWidget):
 
 
 class TreeItemDelegate(QtGui.QStyledItemDelegate):
-    """ A delegate class to draw wrapped text labels """
+    """A delegate class to draw wrapped text labels"""
 
     # FIXME: sizeHint() should return the size required by the label,
     # which is dependent on the width available, which is different for
@@ -1761,7 +1726,7 @@ class TreeItemDelegate(QtGui.QStyledItemDelegate):
     # TODO: add ability to override editor in item delegate
 
     def sizeHint(self, option, index):
-        """ returns area taken by the text. """
+        """returns area taken by the text."""
         column = index.column()
         item = self.editor._tree.itemFromIndex(index)
         expanded, node, instance = self.editor._get_node_data(item)
@@ -1779,12 +1744,11 @@ class TreeItemDelegate(QtGui.QStyledItemDelegate):
             return QtCore.QSize(*size)
 
     def updateEditorGeometry(self, editor, option, index):
-        """ Update the editor's geometry.
-        """
+        """Update the editor's geometry."""
         editor.setGeometry(option.rect)
 
     def paint(self, painter, option, index):
-        """ Render the contents of the item. """
+        """Render the contents of the item."""
         item = self.editor._tree.itemFromIndex(index)
         expanded, node, instance = self.editor._get_node_data(item)
         column = index.column()
