@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -14,12 +14,11 @@ from traitsui.testing.tester._abstract_target_registry import (
     AbstractTargetRegistry,
 )
 from traitsui.testing.tester._ui_tester_registry.default_registry import (
-    get_default_registries
+    get_default_registries,
 )
 
 
 class TestDefaultRegistry(unittest.TestCase):
-
     def test_load_default_registries(self):
         registries = get_default_registries()
         for registry in registries:
