@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/18/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Define the ViewElements class, which is used to define a (typically
     class-based) hierarchical name space of related ViewElement objects.
@@ -24,8 +17,6 @@
     of its associated class's parent classes.
 """
 
-
-
 from traits.api import HasStrictTraits, List, Dict, Str, Int, Any, TraitError
 
 from .view_element import ViewElement
@@ -39,8 +30,7 @@ content_trait = Dict(str, ViewElement)
 
 
 class ViewElements(HasStrictTraits):
-    """ Defines a hierarchical name space of related ViewElement objects.
-    """
+    """Defines a hierarchical name space of related ViewElement objects."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -50,8 +40,8 @@ class ViewElements(HasStrictTraits):
     content = content_trait
 
     def find(self, name, stack=None):
-        """ Finds a specified ViewElement within the specified (optional) search
-            context.
+        """Finds a specified ViewElement within the specified (optional) search
+        context.
         """
         # Assume search starts from the beginning the of the search order:
         i = 0
@@ -83,8 +73,8 @@ class ViewElements(HasStrictTraits):
         return None
 
     def filter_by(self, klass=None):
-        """ Returns a sorted list of all names accessible from the ViewElements
-            object that are of a specified (ViewElement) type.
+        """Returns a sorted list of all names accessible from the ViewElements
+        object that are of a specified (ViewElement) type.
         """
         if klass is None:
             from . import view
@@ -154,8 +144,7 @@ class ViewElements(HasStrictTraits):
                     del seq[0]
 
     def __repr__(self):
-        """ Returns a "pretty print" version of the ViewElements object.
-        """
+        """Returns a "pretty print" version of the ViewElements object."""
         return self.content.__repr__()
 
 
