@@ -1,19 +1,13 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005--2009, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Judah De Paula <judah@enthought.com>
-#  Date:   2/26/2009
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """
 A Traits UI editor that wraps a WX calendar panel.
 
@@ -37,11 +31,6 @@ from traitsui.wx.text_editor import ReadonlyEditor as TextReadonlyEditor
 logger = logging.getLogger(__name__)
 
 
-# ------------------------------------------------------------------------------
-# --  Simple Editor
-# ------------------------------------------------------------------------------
-
-
 class SimpleEditor(Editor):
     """
     Simple Traits UI date editor.  Shows a text box, and a date-picker widget.
@@ -56,7 +45,9 @@ class SimpleEditor(Editor):
         self.control = date_widget(
             parent,
             size=(120, -1),
-            style=wx.adv.DP_DROPDOWN | wx.adv.DP_SHOWCENTURY | wx.adv.DP_ALLOWNONE,
+            style=wx.adv.DP_DROPDOWN
+            | wx.adv.DP_SHOWCENTURY
+            | wx.adv.DP_ALLOWNONE,
         )
         self.control.Bind(wx.adv.EVT_DATE_CHANGED, self.day_selected)
         return
@@ -75,7 +66,9 @@ class SimpleEditor(Editor):
             try:
                 self.value = datetime.date(year, month, day)
             except ValueError:
-                logger.exception("Invalid date: %d-%d-%d (y-m-d)", (year, month, day))
+                logger.exception(
+                    "Invalid date: %d-%d-%d (y-m-d)", (year, month, day)
+                )
                 raise
         return
 
@@ -100,9 +93,6 @@ class SimpleEditor(Editor):
         return
 
 
-# -- end SimpleEditor definition -----------------------------------------------
-
-
 # ------------------------------------------------------------------------------
 # --  Custom Editor
 # ------------------------------------------------------------------------------
@@ -135,7 +125,7 @@ class wxMouseBoxCalendarCtrl(wx.adv.CalendarCtrl):
     """
 
     def __init__(self, *args, **kwargs):
-        super(wxMouseBoxCalendarCtrl, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self.selecting = False
         self.box_selected = []
@@ -259,8 +249,6 @@ class wxMouseBoxCalendarCtrl(wx.adv.CalendarCtrl):
         gc.SetBrush(brush)
         gc.DrawRectangle(x, y, w, h)
 
-# -- end wxMouseBoxCalendarCtrl ------------------------------------------------
-
 
 class MultiCalendarCtrl(wx.Panel):
     """
@@ -286,9 +274,9 @@ class MultiCalendarCtrl(wx.Panel):
         months,
         padding,
         *args,
-        **kwargs
+        **kwargs,
     ):
-        super(MultiCalendarCtrl, self).__init__(parent, ID, *args, **kwargs)
+        super().__init__(parent, ID, *args, **kwargs)
 
         self.sizer = wx.BoxSizer()
         self.SetSizer(self.sizer)
@@ -379,7 +367,7 @@ class MultiCalendarCtrl(wx.Panel):
         return new_date
 
     def selected_list_changed(self, evt=None):
-        """ Update the date colors of the days in the widgets. """
+        """Update the date colors of the days in the widgets."""
         for cal in self.cal_ctrls:
             cur_month = cal.GetDate().GetMonth() + 1
             cur_year = cal.GetDate().GetYear()
@@ -397,14 +385,10 @@ class MultiCalendarCtrl(wx.Panel):
                 try:
                     paint_day = datetime.date(cur_year, cur_month, day)
                     if not self.allow_future and paint_day > self.today:
-                        attr = wx.adv.CalendarDateAttr(
-                            colText=UNAVAILABLE_FG
-                        )
+                        attr = wx.adv.CalendarDateAttr(colText=UNAVAILABLE_FG)
                         cal.SetAttr(day, attr)
                     elif paint_day in selected_days:
-                        attr = wx.adv.CalendarDateAttr(
-                            colText=SELECTED_FG
-                        )
+                        attr = wx.adv.CalendarDateAttr(colText=SELECTED_FG)
                         cal.SetAttr(day, attr)
                     else:
                         cal.ResetAttr(day)
@@ -476,9 +460,7 @@ class MultiCalendarCtrl(wx.Panel):
                         (date.year, date.month, date.day)
                         > (self.today.year, self.today.month, self.today.day)
                     ):
-                        attr = wx.adv.CalendarDateAttr(
-                            colText=UNAVAILABLE_FG
-                        )
+                        attr = wx.adv.CalendarDateAttr(colText=UNAVAILABLE_FG)
                     else:
                         attr = wx.adv.CalendarDateAttr(
                             colText=NORMAL_HIGHLIGHT_FG,
@@ -610,7 +592,7 @@ class MultiCalendarCtrl(wx.Panel):
             return
 
     def _shift_drag_update(self, event):
-        """ Shift-drag in progress. """
+        """Shift-drag in progress."""
         cal = event.GetEventObject()
         result, dt, weekday = cal.HitTest(event.GetPosition())
 
@@ -659,7 +641,7 @@ class MultiCalendarCtrl(wx.Panel):
         self._box_select = []
 
     def _weekday_clicked(self, evt):
-        """ A day on the weekday bar has been clicked.  Select all days. """
+        """A day on the weekday bar has been clicked.  Select all days."""
         evt.Skip()
         weekday = evt.GetWeekDay()
         cal = evt.GetEventObject()
@@ -684,7 +666,7 @@ class MultiCalendarCtrl(wx.Panel):
         return
 
     def _left_down(self, event):
-        """ Handle user selection of days. """
+        """Handle user selection of days."""
         event.Skip()
         cal = event.GetEventObject()
         result, dt, weekday = cal.HitTest(event.GetPosition())
@@ -709,7 +691,7 @@ class MultiCalendarCtrl(wx.Panel):
         return
 
     def _left_up(self, event):
-        """ Handle the end of a possible run-selection. """
+        """Handle the end of a possible run-selection."""
         event.Skip()
         cal = event.GetEventObject()
         result, dt, weekday = cal.HitTest(event.GetPosition())
@@ -743,7 +725,7 @@ class MultiCalendarCtrl(wx.Panel):
         return
 
     def _mouse_drag(self, event):
-        """ Called when the mouse in being dragged within the main panel. """
+        """Called when the mouse in being dragged within the main panel."""
         event.Skip()
         cal = event.GetEventObject()
         if not cal.selecting and self._first_date:
@@ -788,9 +770,6 @@ class MultiCalendarCtrl(wx.Panel):
         self.selected_list_changed()
 
 
-# -- end CalendarCtrl ----------------------------------------------------------
-
-
 class CustomEditor(Editor):
     """
     Show multiple months with MultiCalendarCtrl. Allow multi-select.
@@ -853,37 +832,18 @@ class CustomEditor(Editor):
         return
 
 
-# -- end CustomEditor definition -----------------------------------------------
-
-
-# ------------------------------------------------------------------------------
-# --  Text Editor
-# ------------------------------------------------------------------------------
 # TODO: Write me.  Possibly use TextEditor as a model to show a string
 # representation of the date, and have enter-set do a date evaluation.
 class TextEditor(SimpleEditor):
     pass
 
 
-# -- end TextEditor definition -------------------------------------------------
-
-
-# ------------------------------------------------------------------------------
-# --  Readonly Editor
-# ------------------------------------------------------------------------------
-
-
 class ReadonlyEditor(TextReadonlyEditor):
-    """ Use a TextEditor for the view. """
+    """Use a TextEditor for the view."""
 
     def _get_str_value(self):
-        """ Replace the default string value with our own date verision. """
+        """Replace the default string value with our own date verision."""
         if not self.value:
             return self.factory.message
         else:
             return self.value.strftime(self.factory.strftime)
-
-
-# -- end ReadonlyEditor definition ---------------------------------------------
-
-# -- eof -----------------------------------------------------------------------
