@@ -1,19 +1,12 @@
-# -------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2007, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   03/11/2007
-#
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Traits UI MS Flash editor.
 """
@@ -30,8 +23,7 @@ from traitsui.basic_editor_factory import BasicEditorFactory
 
 
 class _FlashEditor(Editor):
-    """ Traits UI Flash editor.
-    """
+    """Traits UI Flash editor."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -41,15 +33,15 @@ class _FlashEditor(Editor):
     scrollable = True
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control = FlashWindow(parent)
         self.set_tooltip()
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         value = self.str_value.strip()
         if value.find("://") < 0:
