@@ -1,34 +1,22 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/21/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines file editors for the wxPython user interface toolkit.
 """
 
+from os.path import abspath, split, splitext, isfile, exists
 
 import wx
 
-from os.path import abspath, split, splitext, isfile, exists
-
-from traits.api import List, Str, Event, Any, on_trait_change, TraitError
-
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.file_editor file.
-from traitsui.editors.file_editor import ToolkitEditorFactory
+from pyface.api import FileDialog, OK
+from traits.api import List, Str, Event, Any, observe, TraitError
 
 from .text_editor import SimpleEditor as SimpleTextEditor
 
@@ -47,9 +35,9 @@ filter_trait = List(Str)
 
 
 class SimpleEditor(SimpleTextEditor):
-    """ Simple style of file editor, consisting of a text field and a **Browse**
-        button that opens a file-selection dialog box. The user can also drag
-        and drop a file onto this control.
+    """Simple style of file editor, consisting of a text field and a **Browse**
+    button that opens a file-selection dialog box. The user can also drag
+    and drop a file onto this control.
     """
 
     #: The history control (used if the factory 'entries' > 0):
@@ -59,8 +47,8 @@ class SimpleEditor(SimpleTextEditor):
     popup = Any()
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control = panel = TraitsUIPanel(parent, -1)
         sizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -78,7 +66,9 @@ class SimpleEditor(SimpleTextEditor):
         else:
             if factory.enter_set:
                 control = wx.TextCtrl(panel, -1, "", style=wx.TE_PROCESS_ENTER)
-                panel.Bind(wx.EVT_TEXT_ENTER, self.update_object, id=control.GetId())
+                panel.Bind(
+                    wx.EVT_TEXT_ENTER, self.update_object, id=control.GetId()
+                )
             else:
                 control = wx.TextCtrl(panel, -1, "")
 
@@ -93,7 +83,7 @@ class SimpleEditor(SimpleTextEditor):
             pad = 8
 
         self._file_name = control
-        sizer.Add(control, 1, wx.EXPAND | wx.ALIGN_CENTER)
+        sizer.Add(control, 1, wx.EXPAND)
         sizer.Add(button, 0, wx.LEFT | wx.ALIGN_CENTER, pad)
         panel.Bind(wx.EVT_BUTTON, self.show_file_dialog, id=button.GetId())
         panel.SetDropTarget(FileDropTarget(self))
@@ -103,8 +93,7 @@ class SimpleEditor(SimpleTextEditor):
         self.set_tooltip(control)
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
         panel = self.control
         panel.Unbind(wx.EVT_BUTTON, id=self._button.GetId())
         self._button = None
@@ -118,25 +107,24 @@ class SimpleEditor(SimpleTextEditor):
             panel.Unbind(wx.EVT_TEXT_ENTER, id=control.GetId())
             panel.Unbind(wx.EVT_TEXT, id=control.GetId())
 
-        super(SimpleEditor, self).dispose()
+        super().dispose()
 
-    @on_trait_change("history:value")
-    def _history_value_changed(self, value):
-        """ Handles the history 'value' trait being changed.
-        """
+    @observe("history:value")
+    def _history_value_changed(self, event):
+        """Handles the history 'value' trait being changed."""
+        value = event.new
         if not self._no_update:
             self._update(value)
 
     def update_object(self, event):
-        """ Handles the user changing the contents of the edit control.
-        """
+        """Handles the user changing the contents of the edit control."""
         if isinstance(event, wx.FocusEvent):
             event.Skip()
         self._update(self._file_name.GetValue())
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         if self.history is not None:
             self._no_update = True
@@ -146,33 +134,30 @@ class SimpleEditor(SimpleTextEditor):
             self._file_name.SetValue(self.str_value)
 
     def show_file_dialog(self, event):
-        """ Displays the pop-up file dialog.
-        """
+        """Displays the pop-up file dialog."""
         if self.history is not None:
             self.popup = self._create_file_popup()
         else:
             dlg = self._create_file_dialog()
-            rc = dlg.ShowModal() == wx.ID_OK
-            file_name = abspath(dlg.GetPath())
-            dlg.Destroy()
-            if rc:
-                if self.factory.truncate_ext:
-                    file_name = splitext(file_name)[0]
+            dlg.open()
 
-                self.value = file_name
+            if dlg.return_code == OK:
+                if self.factory.truncate_ext:
+                    self.value = splitext(dlg.path)[0]
+                else:
+                    self.value = dlg.path
                 self.update_editor()
 
     def get_error_control(self):
-        """ Returns the editor's control for indicating error status.
-        """
+        """Returns the editor's control for indicating error status."""
         return self._file_name
 
     # -- Traits Event Handlers ------------------------------------------------
 
-    @on_trait_change("popup:value")
-    def _popup_value_changed(self, file_name):
-        """ Handles the popup value being changed.
-        """
+    @observe("popup:value")
+    def _popup_value_changed(self, event):
+        """Handles the popup value being changed."""
+        file_name = event.new
         if self.factory.truncate_ext:
             file_name = splitext(file_name)[0]
 
@@ -181,17 +166,16 @@ class SimpleEditor(SimpleTextEditor):
         self.history.set_value(self.str_value)
         self._no_update = False
 
-    @on_trait_change("popup:closed")
-    def _popup_closed_changed(self):
-        """ Handles the popup control being closed.
-        """
+    @observe("popup:closed")
+    def _popup_closed_changed(self, event):
+        """Handles the popup control being closed."""
         self.popup = None
 
     # -- UI preference save/restore interface ---------------------------------
 
     def restore_prefs(self, prefs):
-        """ Restores any saved user preference information associated with the
-            editor.
+        """Restores any saved user preference information associated with the
+        editor.
         """
         if self.history is not None:
             self.history.history = prefs.get("history", [])[
@@ -199,8 +183,7 @@ class SimpleEditor(SimpleTextEditor):
             ]
 
     def save_prefs(self):
-        """ Returns any user preference information associated with the editor.
-        """
+        """Returns any user preference information associated with the editor."""
         if self.history is not None:
             return {"history": self.history.history[:]}
 
@@ -209,36 +192,22 @@ class SimpleEditor(SimpleTextEditor):
     # -- Private Methods ------------------------------------------------------
 
     def _create_file_dialog(self):
-        """ Creates the correct type of file dialog.
-        """
+        """Creates the correct type of file dialog."""
         if len(self.factory.filter) > 0:
-            wildcard = "|".join(self.factory.filter[:])
+            wildcard = "|".join(self.factory.filter)
         else:
             wildcard = "All Files (*.*)|*.*"
 
-        if self.factory.dialog_style == "save":
-            style = wx.FD_SAVE
-        elif self.factory.dialog_style == "open":
-            style = wx.FD_OPEN
-        else:
-            style = wx.FD_DEFAULT_STYLE
-
-        directory, filename = split(self._get_value())
-
-        dlg = wx.FileDialog(
-            self.control,
-            defaultDir=directory,
-            defaultFile=filename,
-            message="Select a File",
+        dlg = FileDialog(
+            parent=self.get_control_widget(),
+            default_path=self._file_name.text(),
+            action="save" if self.factory.dialog_style == "save as" else "open",
             wildcard=wildcard,
-            style=style,
         )
-
         return dlg
 
     def _create_file_popup(self):
-        """ Creates the correct type of file popup.
-        """
+        """Creates the correct type of file popup."""
         return PopupFile(
             control=self.control,
             file_name=self.str_value,
@@ -247,8 +216,7 @@ class SimpleEditor(SimpleTextEditor):
         )
 
     def _update(self, file_name):
-        """ Updates the editor value with a specified file name.
-        """
+        """Updates the editor value with a specified file name."""
         try:
             if self.factory.truncate_ext:
                 file_name = splitext(file_name)[0]
@@ -258,8 +226,7 @@ class SimpleEditor(SimpleTextEditor):
             pass
 
     def _get_value(self):
-        """ Returns the current file name from the edit control.
-        """
+        """Returns the current file name from the edit control."""
         if self.history is not None:
             return self.history.value
 
@@ -267,8 +234,7 @@ class SimpleEditor(SimpleTextEditor):
 
 
 class CustomEditor(SimpleTextEditor):
-    """ Custom style of file editor, consisting of a file system tree view.
-    """
+    """Custom style of file editor, consisting of a file system tree view."""
 
     #: Is the file editor scrollable? This value overrides the default.
     scrollable = True
@@ -283,8 +249,8 @@ class CustomEditor(SimpleTextEditor):
     dclick = Event()
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         style = self.get_style()
         factory = self.factory
@@ -306,18 +272,16 @@ class CustomEditor(SimpleTextEditor):
         self.set_tooltip()
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
         tree, self._tree = self._tree, None
 
         tree.Unbind(wx.EVT_TREE_SEL_CHANGED)
         tree.Unbind(wx.EVT_TREE_ITEM_ACTIVATED)
 
-        super(CustomEditor, self).dispose()
+        super().dispose()
 
     def update_object(self, event):
-        """ Handles the user changing the contents of the edit control.
-        """
+        """Handles the user changing the contents of the edit control."""
         if self.control is not None:
             path = self.control.GetPath()
             if self.factory.allow_dir or isfile(path):
@@ -327,41 +291,35 @@ class CustomEditor(SimpleTextEditor):
                 self.value = path
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         if exists(self.str_value):
             self.control.SetPath(self.str_value)
 
     def get_style(self):
-        """ Returns the basic style to use for the control.
-        """
+        """Returns the basic style to use for the control."""
         return wx.DIRCTRL_EDIT_LABELS
 
     def get_error_control(self):
-        """ Returns the editor's control for indicating error status.
-        """
+        """Returns the editor's control for indicating error status."""
         return self._tree
 
     def _filter_changed(self):
-        """ Handles the 'filter' trait being changed.
-        """
+        """Handles the 'filter' trait being changed."""
         self.control.SetFilter("|".join(self.filter[:]))
 
     def _on_dclick(self, event):
-        """ Handles the user double-clicking on a file name.
-        """
+        """Handles the user double-clicking on a file name."""
         self.dclick = self.control.GetPath()
 
     def _on_tooltip(self, event):
-        """ Handles the user hovering on a file name for a tooltip.
-        """
+        """Handles the user hovering on a file name for a tooltip."""
         text = self._tree.GetItemText(event.GetItem())
         event.SetToolTip(text)
 
     def _reload_changed(self):
-        """ Handles the 'reload' trait being changed.
-        """
+        """Handles the 'reload' trait being changed."""
         self.control.ReCreateTree()
 
 
@@ -379,8 +337,7 @@ class PopupFile(PopupControl):
     # -- PopupControl Method Overrides ----------------------------------------
 
     def create_control(self, parent):
-        """ Creates the file control and gets it ready for use.
-        """
+        """Creates the file control and gets it ready for use."""
         style = self.get_style()
         if len(self.filter) > 0:
             style |= wx.DIRCTRL_SHOW_FILTERS
@@ -397,20 +354,17 @@ class PopupFile(PopupControl):
         self._tree = self._files = None
 
     def get_style(self):
-        """ Returns the base style for this type of popup.
-        """
+        """Returns the base style for this type of popup."""
         return wx.DIRCTRL_EDIT_LABELS
 
     def is_valid(self, path):
-        """ Returns whether or not the path is valid.
-        """
+        """Returns whether or not the path is valid."""
         return isfile(path)
 
     # -- Private Methods ------------------------------------------------------
 
     def _select_file(self, event):
-        """ Handles a file being selected in the file control.
-        """
+        """Handles a file being selected in the file control."""
         path = self._files.GetPath()
 
         # We have to make sure the selected path is different than the original
@@ -432,8 +386,7 @@ class PopupFile(PopupControl):
 
 
 class FileDropTarget(wx.FileDropTarget):
-    """ A target for a drag and drop operation, which accepts a file.
-    """
+    """A target for a drag and drop operation, which accepts a file."""
 
     def __init__(self, editor):
         wx.FileDropTarget.__init__(self)
