@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   12/22/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Trait definition for a wxPython-based font.
 """
@@ -21,6 +14,7 @@
 
 import wx
 
+from pyface.font import Font as PyfaceFont
 from traits.api import Trait, TraitHandler, TraitError
 
 # -------------------------------------------------------------------------
@@ -35,10 +29,15 @@ font_families = {
     "script": wx.FONTFAMILY_SCRIPT,
     "swiss": wx.FONTFAMILY_SWISS,
     "modern": wx.FONTFAMILY_MODERN,
+    "typewriter": wx.FONTFAMILY_TELETYPE,
 }
 
 # Mapping of strings to wxFont styles
-font_styles = {"slant": wx.FONTSTYLE_SLANT, "italic": wx.FONTSTYLE_ITALIC}
+font_styles = {
+    "slant": wx.FONTSTYLE_SLANT,
+    "oblique": wx.FONTSTYLE_SLANT,
+    "italic": wx.FONTSTYLE_ITALIC,
+}
 
 # Mapping of strings wxFont weights
 font_weights = {"light": wx.FONTWEIGHT_LIGHT, "bold": wx.FONTWEIGHT_BOLD}
@@ -48,19 +47,27 @@ font_noise = ["pt", "point", "family"]
 
 
 def font_to_str(font):
-    """ Converts a wx.Font into a string description of itself.
-    """
+    """Converts a wx.Font into a string description of itself."""
+    family = {
+        wx.FONTFAMILY_DECORATIVE: "decorative family",
+        wx.FONTFAMILY_ROMAN: "roman family",
+        wx.FONTFAMILY_SCRIPT: "script family",
+        wx.FONTFAMILY_SWISS: "swiss family",
+        wx.FONTFAMILY_MODERN: "modern family",
+        wx.FONTFAMILY_TELETYPE: "typewriter family",
+    }.get(font.GetFamily(), "")
     weight = {wx.FONTWEIGHT_LIGHT: " Light", wx.FONTWEIGHT_BOLD: " Bold"}.get(
         font.GetWeight(), ""
     )
-    style = {wx.FONTSTYLE_SLANT: " Slant", wx.FONTSTYLE_ITALIC: " Italic"}.get(
+    style = {wx.FONTSTYLE_SLANT: " Oblique", wx.FONTSTYLE_ITALIC: " Italic"}.get(
         font.GetStyle(), ""
     )
     underline = ""
     if font.GetUnderlined():
         underline = " underline"
-    return "%s point %s%s%s%s" % (
+    return "%s point %s%s%s%s%s" % (
         font.GetPointSize(),
+        family,
         font.GetFaceName(),
         style,
         weight,
@@ -69,10 +76,11 @@ def font_to_str(font):
 
 
 def create_traitsfont(value):
-    """ Create a TraitFont object from a string description.
-    """
+    """Create a TraitsFont object from a string description."""
+    if isinstance(value, PyfaceFont):
+        return TraitsFont(value.to_toolkit())
     if isinstance(value, wx.Font):
-        value = font_to_str(value)
+        return TraitsFont(value)
 
     point_size = None
     family = wx.FONTFAMILY_DEFAULT
@@ -95,26 +103,29 @@ def create_traitsfont(value):
                 try:
                     point_size = int(lword)
                     continue
-                except:
+                except ValueError:
                     pass
             facename.append(word)
-    return TraitsFont(
-        point_size or 10, family, style, weight, underline, " ".join(facename)
-    )
+    if facename:
+        font = TraitsFont(
+            point_size or 10, family, style, weight, underline, " ".join(facename)
+        )
+        return font
+    else:
+        return TraitsFont(
+            point_size or 10, family, style, weight, underline
+        )
 
 
 class TraitsFont(wx.Font):
-    """ A Traits-specific wx.Font.
-    """
+    """A Traits-specific wx.Font."""
 
     def __reduce_ex__(self, protocol):
-        """ Returns the pickleable form of a TraitsFont object.
-        """
+        """Returns the pickleable form of a TraitsFont object."""
         return (create_traitsfont, (font_to_str(self),))
 
     def __str__(self):
-        """ Returns a printable form of the font.
-        """
+        """Returns a printable form of the font."""
         return font_to_str(self)
 
 
@@ -124,13 +135,13 @@ class TraitsFont(wx.Font):
 
 
 class TraitWXFont(TraitHandler):
-    """ Ensures that values assigned to a trait attribute are valid font
+    """Ensures that values assigned to a trait attribute are valid font
     descriptor strings; the value actually assigned is the corresponding
     TraitsFont.
     """
 
     def validate(self, object, name, value):
-        """ Validates that the value is a valid font descriptor string. If so,
+        """Validates that the value is a valid font descriptor string. If so,
         it returns the corresponding TraitsFont; otherwise, it raises a
         TraitError.
         """
