@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/25/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines helper functions and classes used to define wxPython-based trait
     editors and trait editor factories.
@@ -44,14 +37,15 @@ from traits.api import (
 
 from traitsui.ui_traits import convert_image, SequenceTypes
 
+from pyface.api import SystemMetrics
+
 from pyface.timer.api import do_later
 
-from .constants import standard_bitmap_width, screen_dx, screen_dy
+from .constants import standard_bitmap_width
 
 from .editor import Editor
 
 
-
 # -------------------------------------------------------------------------
 #  Trait definitions:
 # -------------------------------------------------------------------------
@@ -73,8 +67,7 @@ traits_path = None
 
 
 def bitmap_cache(name, standard_size, path=None):
-    """ Converts an image file name to a cached bitmap.
-    """
+    """Converts an image file name to a cached bitmap."""
     global app_path, traits_path
 
     if name[:1] == "@":
@@ -129,22 +122,20 @@ def bitmap_cache(name, standard_size, path=None):
 
 
 def choice_width(values):
-    """ Returns an appropriate width for a wxChoice widget based upon the list
-        of values it contains:
+    """Returns an appropriate width for a wxChoice widget based upon the list
+    of values it contains:
     """
     return max([len(x) for x in values]) * 6
 
 
 def save_window(ui):
-    """ Saves the user preference items for a specified UI.
-    """
+    """Saves the user preference items for a specified UI."""
     control = ui.control
     ui.save_prefs(control.GetPosition() + control.GetSize())
 
 
 def restore_window(ui, is_popup=False):
-    """ Restores the user preference items for a specified UI.
-    """
+    """Restores the user preference items for a specified UI."""
     prefs = ui.restore_prefs()
     if prefs is not None:
         x, y, dx, dy = prefs
@@ -167,11 +158,11 @@ def restore_window(ui, is_popup=False):
 
 
 def find_closest_display(x, y):
-    """ For a virtual screen position, find the closest display.
-        There are a few reasons to use this function:
-            * the number of displays changed
-            * the size of the displays changed
-            * the orientation of one or more displays changed.
+    """For a virtual screen position, find the closest display.
+    There are a few reasons to use this function:
+        * the number of displays changed
+        * the size of the displays changed
+        * the orientation of one or more displays changed.
     """
     closest = None
     for display_num in range(wx.Display.GetCount()):
@@ -194,8 +185,8 @@ def find_closest_display(x, y):
 
 
 def get_position_for_display(x, y, dx, dy, display):
-    """ calculates a valid position and size for a window to fit
-        inside a display
+    """calculates a valid position and size for a window to fit
+    inside a display
     """
     dis_x, dis_y, dis_w, dis_h = display.GetGeometry()
     dx = min(dx, dis_w)
@@ -215,8 +206,8 @@ def get_position_for_display(x, y, dx, dy, display):
 
 
 def position_window(window, width=None, height=None, parent=None):
-    """ Positions a window on the screen with a specified width and height so
-        that the window completely fits on the screen if possible.
+    """Positions a window on the screen with a specified width and height so
+    that the window completely fits on the screen if possible.
     """
     dx, dy = window.GetSize()
     width = width or dx
@@ -228,7 +219,10 @@ def position_window(window, width=None, height=None, parent=None):
     if parent is None:
         # Center the popup on the screen:
         window.SetSize(
-            (screen_dx - width) // 2, (screen_dy - height) // 2, width, height
+            (SystemMetrics().screen_width - width) // 2,
+            (SystemMetrics().screen_height - height) // 2,
+            width,
+            height,
         )
         return
 
@@ -242,8 +236,8 @@ def position_window(window, width=None, height=None, parent=None):
         x, y, parent_dx, parent_dy = parent
 
     adjacent = getattr(window, "_kind", "popup") == "popup"
-    width = min(max(parent_dx, width), screen_dx)
-    height = min(height, screen_dy)
+    width = min(max(parent_dx, width), SystemMetrics().screen_width)
+    height = min(height, SystemMetrics().screen_height)
 
     closest = find_closest_display(x, y)
 
@@ -256,8 +250,7 @@ def position_window(window, width=None, height=None, parent=None):
 
 
 def top_level_window_for(control):
-    """ Returns the top-level window for a specified control.
-    """
+    """Returns the top-level window for a specified control."""
     parent = control.GetParent()
     while parent is not None:
         control = parent
@@ -266,52 +259,15 @@ def top_level_window_for(control):
     return control
 
 
-def enum_values_changed(values):
-    """ Recomputes the mappings for a new set of enumeration values.
-    """
-
-    if isinstance(values, dict):
-        data = [(str(v), n) for n, v in values.items()]
-        if len(data) > 0:
-            data.sort(key=itemgetter(0))
-            col = data[0][0].find(":") + 1
-            if col > 0:
-                data = [(n[col:], v) for n, v in data]
-    elif not isinstance(values, SequenceTypes):
-        handler = values
-        if isinstance(handler, CTrait):
-            handler = handler.handler
-        if not isinstance(handler, BaseTraitHandler):
-            raise TraitError("Invalid value for 'values' specified")
-        if handler.is_mapped:
-            data = [(str(n), n) for n in handler.map.keys()]
-            data.sort(key=itemgetter(0))
-        else:
-            data = [(str(v), v) for v in handler.values]
-    else:
-        data = [(str(v), v) for v in values]
-
-    names = [x[0] for x in data]
-    mapping = {}
-    inverse_mapping = {}
-    for name, value in data:
-        mapping[name] = value
-        inverse_mapping[value] = name
-
-    return (names, mapping, inverse_mapping)
-
-
 def disconnect(control, *events):
-    """ Disconnects a wx event handle from its associated control.
-    """
+    """Disconnects a wx event handle from its associated control."""
     id = control.GetId()
     for event in events:
         control.Unbind(event, id=id)
 
 
 def disconnect_no_id(control, *events):
-    """ Disconnects a wx event handle from its associated control.
-    """
+    """Disconnects a wx event handle from its associated control."""
     for event in events:
         control.Unbind(event)
 
@@ -324,8 +280,8 @@ def disconnect_no_id(control, *events):
 
 class TraitsUIPanel(wx.Panel):
     def __init__(self, parent, *args, **kw):
-        """ Creates a wx.Panel that correctly sets its background color to be
-            the same as its parents.
+        """Creates a wx.Panel that correctly sets its background color to be
+        the same as its parents.
         """
         bg_color = kw.pop("bg_color", None)
         wx.Panel.__init__(self, parent, *args, **kw)
@@ -340,15 +296,15 @@ class TraitsUIPanel(wx.Panel):
             self.SetBackgroundColour(attr.colBg)
 
     def OnChildFocus(self, event):
-        """ If the ChildFocusEvent contains one of the Panel's direct children,
-            then we will Skip it to let it pass up the widget hierarchy.
+        """If the ChildFocusEvent contains one of the Panel's direct children,
+        then we will Skip it to let it pass up the widget hierarchy.
 
-            Otherwise, we consume the event to make sure it doesn't go any
-            farther. This works around a problem in wx 2.8.8.1 where each Panel
-            in a nested hierarchy generates many events that might consume too
-            many resources. We do, however, let one event bubble up to the top
-            so that it may inform a top-level ScrolledPanel that a descendant
-            has acquired focus.
+        Otherwise, we consume the event to make sure it doesn't go any
+        farther. This works around a problem in wx 2.8.8.1 where each Panel
+        in a nested hierarchy generates many events that might consume too
+        many resources. We do, however, let one event bubble up to the top
+        so that it may inform a top-level ScrolledPanel that a descendant
+        has acquired focus.
         """
         if event.GetWindow() in self.GetChildren():
             event.Skip()
@@ -362,17 +318,18 @@ class TraitsUIPanel(wx.Panel):
 #  'ChildFocusOverride' class:
 # -------------------------------------------------------------------------
 
-class ChildFocusOverride(wx.EvtHandler):
-    """ Override the scroll-to-focus behaviour in wx 2.8.8's ScrolledWindow
-        C++ implementation for ScrolledPanel.
 
-        Instantiating this class with the ScrolledPanel will register the
-        new instance as the event handler for the panel.
+class ChildFocusOverride(wx.EvtHandler):
+    """Override the scroll-to-focus behaviour in wx 2.8.8's ScrolledWindow
+    C++ implementation for ScrolledPanel.
+
+    Instantiating this class with the ScrolledPanel will register the
+    new instance as the event handler for the panel.
     """
 
     def __init__(self, window):
         self.window = window
-        super(ChildFocusOverride, self).__init__()
+        super().__init__()
 
         # Make self the event handler for the window.
         window.PushEventHandler(self)
@@ -414,11 +371,12 @@ class TraitsUIScrolledPanel(wx.lib.scrolledpanel.ScrolledPanel):
 
     def Destroy(self):
         from traitsui.wx.toolkit import _popEventHandlers
+
         _popEventHandlers(self, ChildFocusOverride)
         super().Destroy()
 
     def OnChildFocus(self, event):
-        """ Handle a ChildFocusEvent.
+        """Handle a ChildFocusEvent.
 
         Returns a boolean so it can be used as a library call, too.
         """
@@ -427,9 +385,9 @@ class TraitsUIScrolledPanel(wx.lib.scrolledpanel.ScrolledPanel):
         return True
 
     def ScrollChildIntoView(self, child):
-        """ Scrolls the panel such that the specified child window is in view.
-            This method overrides the original in the base class so that
-            nested subpanels are handled correctly.
+        """Scrolls the panel such that the specified child window is in view.
+        This method overrides the original in the base class so that
+        nested subpanels are handled correctly.
         """
         if child is None:
             return
@@ -510,8 +468,8 @@ handlers = (
 
 
 def init_wx_handlers(control, object, prefix=""):
-    """ Initializes a standard set of wx event handlers for a specified control
-        and object using a specified prefix.
+    """Initializes a standard set of wx event handlers for a specified control
+    and object using a specified prefix.
     """
     global handlers
 
@@ -523,8 +481,7 @@ def init_wx_handlers(control, object, prefix=""):
 
 class GroupEditor(Editor):
     def __init__(self, **traits):
-        """ Initializes the object.
-        """
+        """Initializes the object."""
         self.trait_set(**traits)
 
 
@@ -560,9 +517,8 @@ class PopupControl(HasPrivateTraits):
     # -- Public Methods -------------------------------------------------------
 
     def __init__(self, **traits):
-        """ Initializes the object.
-        """
-        super(PopupControl, self).__init__(**traits)
+        """Initializes the object."""
+        super().__init__(**traits)
 
         style = wx.SIMPLE_BORDER
         if self.resizable:
@@ -575,31 +531,29 @@ class PopupControl(HasPrivateTraits):
         popup.Show()
 
     def create_control(self):
-        """ Creates the control.
+        """Creates the control.
 
-            Must be overridden by a subclass.
+        Must be overridden by a subclass.
         """
         raise NotImplementedError
 
     def dispose(self):
-        """ Called when the popup is being closed to allow any custom clean-up.
+        """Called when the popup is being closed to allow any custom clean-up.
 
-            Can be overridden by a subclass.
+        Can be overridden by a subclass.
         """
         pass
 
     # -- Event Handlers -------------------------------------------------------
 
     def _value_changed(self, value):
-        """ Handles the 'value' being changed.
-        """
+        """Handles the 'value' being changed."""
         do_later(self._close_popup)
 
     # -- Private Methods ------------------------------------------------------
 
     def _position_control(self):
-        """ Initializes the popup control's initial position and size.
-        """
+        """Initializes the popup control's initial position and size."""
         # Calculate the desired size of the popup control:
         px, cy = self.control.ClientToScreen(0, 0)
         cdx, cdy = self.control.GetSize()
@@ -608,9 +562,9 @@ class PopupControl(HasPrivateTraits):
 
         # Calculate the best position and size for the pop-up:
         py = cy + cdy
-        if (py + pdy) > screen_dy:
+        if (py + pdy) > SystemMetrics().screen_height:
             if (cy - pdy) < 0:
-                bottom = screen_dy - py
+                bottom = SystemMetrics().screen_height - py
                 if cy > bottom:
                     py, pdy = 0, cy
                 else:
@@ -622,14 +576,12 @@ class PopupControl(HasPrivateTraits):
         self.popup.SetSize(px, py, pdx, pdy)
 
     def _on_close_popup(self, event):
-        """ Closes the popup control when it is deactivated.
-        """
+        """Closes the popup control when it is deactivated."""
         if not event.GetActive():
             self._close_popup()
 
     def _close_popup(self):
-        """ Closes the dialog.
-        """
+        """Closes the dialog."""
         self.popup.Unbind(wx.EVT_ACTIVATE)
         self.dispose()
         self.closed = True
@@ -638,11 +590,11 @@ class PopupControl(HasPrivateTraits):
 
 
 class BufferDC(wx.MemoryDC):
-    """ An off-screen buffer class.
+    """An off-screen buffer class.
 
-        This class implements a off-screen output buffer. Data is meant to
-        be drawn in the buffer and then blitted directly to the output device
-        context.
+    This class implements a off-screen output buffer. Data is meant to
+    be drawn in the buffer and then blitted directly to the output device
+    context.
     """
 
     def __init__(self, dc, width=None, height=None):
@@ -663,8 +615,8 @@ class BufferDC(wx.MemoryDC):
         self.SetFont(dc.GetFont())
 
     def copy(self, x=0, y=0):
-        """ Performs the blit of the buffer contents to the specified device
-            context location.
+        """Performs the blit of the buffer contents to the specified device
+        context location.
         """
         self.dc.Blit(
             x, y, self.bitmap.GetWidth(), self.bitmap.GetHeight(), self, 0, 0
@@ -672,13 +624,13 @@ class BufferDC(wx.MemoryDC):
 
 
 class Slider(wx.Slider):
-    """ This is a 'fixed' version of the wx.Slider control which does not
-        erase its background, which can cause a lot of update flicker and is
-        completely unnecessary.
+    """This is a 'fixed' version of the wx.Slider control which does not
+    erase its background, which can cause a lot of update flicker and is
+    completely unnecessary.
     """
 
     def __init__(self, *args, **kw):
-        super(Slider, self).__init__(*args, **kw)
+        super().__init__(*args, **kw)
 
         self.Bind(wx.EVT_ERASE_BACKGROUND, self._erase_background)
 
@@ -687,4 +639,4 @@ class Slider(wx.Slider):
 
     def Destroy(self):
         self.Unbind(wx.EVT_ERASE_BACKGROUND)
-        super().Destroy()
\ No newline at end of file
+        super().Destroy()
