@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/21/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the a text entry field (actually a combo-box) with a drop-down list
     of values previously entered into the control.
@@ -56,8 +49,7 @@ class HistoryControl(HasPrivateTraits):
     # -- Public Methods -------------------------------------------------------
 
     def create_control(self, parent):
-        """ Creates the control.
-        """
+        """Creates the control."""
         self.control = control = wx.ComboBox(
             parent,
             -1,
@@ -69,15 +61,18 @@ class HistoryControl(HasPrivateTraits):
         )
         parent.Bind(wx.EVT_COMBOBOX, self._update_value, id=control.GetId())
         control.Bind(wx.EVT_KILL_FOCUS, self._kill_focus)
-        parent.Bind(wx.EVT_TEXT_ENTER, self._update_text_value, id=control.GetId())
+        parent.Bind(
+            wx.EVT_TEXT_ENTER, self._update_text_value, id=control.GetId()
+        )
         if self.auto_set:
-            parent.Bind(wx.EVT_TEXT, self._update_value_only, id=control.GetId())
+            parent.Bind(
+                wx.EVT_TEXT, self._update_value_only, id=control.GetId()
+            )
 
         return control
 
     def dispose(self):
-        """ Disposes of the control at the end of its life cycle.
-        """
+        """Disposes of the control at the end of its life cycle."""
         control, self.control = self.control, None
         parent = control.GetParent()
         parent.Bind(wx.EVT_COMBOBOX, None, id=control.GetId())
@@ -85,15 +80,13 @@ class HistoryControl(HasPrivateTraits):
         control.Unbind(wx.EVT_KILL_FOCUS)
 
     def set_value(self, value):
-        """ Sets the specified value and adds it to the history.
-        """
+        """Sets the specified value and adds it to the history."""
         self._update(value)
 
     # -- Traits Event Handlers ------------------------------------------------
 
     def _value_changed(self, value):
-        """ Handles the 'value' trait being changed.
-        """
+        """Handles the 'value' trait being changed."""
         if not self._no_update:
             control = self.control
             if control is not None:
@@ -101,8 +94,7 @@ class HistoryControl(HasPrivateTraits):
                 self._restore = False
 
     def _history_changed(self):
-        """ Handles the 'history' being changed.
-        """
+        """Handles the 'history' being changed."""
         if not self._no_update:
             if self._first_time is None:
                 self._first_time = False
@@ -112,8 +104,7 @@ class HistoryControl(HasPrivateTraits):
             self._load_history(select=False)
 
     def _error_changed(self, error):
-        """ Handles the 'error' trait being changed.
-        """
+        """Handles the 'error' trait being changed."""
         if error:
             self.control.SetBackgroundColour(ErrorColor)
         else:
@@ -124,36 +115,33 @@ class HistoryControl(HasPrivateTraits):
     # -- Wx Event Handlers ----------------------------------------------------
 
     def _update_value(self, event):
-        """ Handles the user selecting something from the drop-down list of the
-            combobox.
+        """Handles the user selecting something from the drop-down list of the
+        combobox.
         """
         self._update(event.GetString())
 
     def _update_value_only(self, event):
-        """ Handles the user typing into the text field in 'auto_set' mode.
-        """
+        """Handles the user typing into the text field in 'auto_set' mode."""
         self._no_update = True
         self.value = event.GetString()
         self._no_update = False
 
     def _update_text_value(self, event, select=True):
-        """ Handles the user typing something into the text field of the
-            combobox.
+        """Handles the user typing something into the text field of the
+        combobox.
         """
         if not self._no_update:
             self._update(self.control.GetValue(), select)
 
     def _kill_focus(self, event):
-        """ Handles the combobox losing focus.
-        """
+        """Handles the combobox losing focus."""
         self._update_text_value(event, False)
         event.Skip()
 
     # -- Private Methods ------------------------------------------------------
 
     def _update(self, value, select=True):
-        """ Updates the value and history list based on a specified value.
-        """
+        """Updates the value and history list based on a specified value."""
         self._no_update = True
 
         if value.strip() != "":
@@ -170,8 +158,7 @@ class HistoryControl(HasPrivateTraits):
         self._no_update = False
 
     def _load_history(self, restore=None, select=True):
-        """ Loads the current history list into the control.
-        """
+        """Loads the current history list into the control."""
         control = self.control
         control.Freeze()
 
@@ -186,8 +173,7 @@ class HistoryControl(HasPrivateTraits):
         do_later(self._thaw_value, restore, select)
 
     def _thaw_value(self, restore, select):
-        """ Restores the value of the combobox control.
-        """
+        """Restores the value of the combobox control."""
         control = self.control
         if control is not None:
             if self._restore:
