@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/21/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the various instance editors for the wxPython user interface
 toolkit.
@@ -23,12 +16,8 @@ toolkit.
 import wx
 
 from pyface.wx.drag_and_drop import PythonDropTarget
-from traits.api import HasTraits, Property
+from traits.api import HasTraits, Instance, Property
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.instance_editor file.
-from traitsui.editors.instance_editor import ToolkitEditorFactory
 from traitsui.ui_traits import AView
 from traitsui.helper import user_name_for
 from traitsui.handler import Handler
@@ -52,7 +41,7 @@ OrientationMap = {
 
 
 class CustomEditor(Editor):
-    """ Custom style of editor for instances. If selection among instances is
+    """Custom style of editor for instances. If selection among instances is
     allowed, the editor displays a combo box listing instances that can be
     selected. If the current instance is editable, the editor displays a panel
     containing trait editors for all the instance's traits.
@@ -82,8 +71,8 @@ class CustomEditor(Editor):
     view = AView
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         factory = self.factory
         if factory.name != "":
@@ -164,7 +153,9 @@ class CustomEditor(Editor):
                 self._choice = choice = wx.Choice(
                     parent, -1, wx.Point(0, 0), wx.Size(-1, -1), []
                 )
-                choice.Bind(wx.EVT_CHOICE, self.update_object, id=choice.GetId())
+                choice.Bind(
+                    wx.EVT_CHOICE, self.update_object, id=choice.GetId()
+                )
             self.control = self._choice
         else:
             sizer = wx.BoxSizer(orientation)
@@ -178,8 +169,7 @@ class CustomEditor(Editor):
         self.sync_value(factory.view_name, "view", "from")
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
         # Make sure we aren't hanging on to any object refs:
         self._object_cache = None
 
@@ -206,17 +196,15 @@ class CustomEditor(Editor):
                 self.rebuild_items, "values_items", remove=True
             )
 
-        super(CustomEditor, self).dispose()
+        super().dispose()
 
     def create_editor(self, parent, sizer):
-        """ Creates the editor control.
-        """
+        """Creates the editor control."""
         self._panel = TraitsUIPanel(parent, -1)
         sizer.Add(self._panel, 1, wx.EXPAND)
 
     def _get_items(self):
-        """ Gets the current list of InstanceChoiceItem items.
-        """
+        """Gets the current list of InstanceChoiceItem items."""
         if self._items is not None:
             return self._items
 
@@ -238,8 +226,7 @@ class CustomEditor(Editor):
         return items
 
     def rebuild_items(self):
-        """ Rebuilds the object selector list.
-        """
+        """Rebuilds the object selector list."""
         # Clear the current cached values:
         self._items = None
 
@@ -266,8 +253,7 @@ class CustomEditor(Editor):
                 pass
 
     def item_for(self, object):
-        """ Returns the InstanceChoiceItem for a specified object.
-        """
+        """Returns the InstanceChoiceItem for a specified object."""
         for item in self.items:
             if item.is_compatible(object):
                 return item
@@ -275,8 +261,7 @@ class CustomEditor(Editor):
         return None
 
     def view_for(self, object, item):
-        """ Returns the view to use for a specified object.
-        """
+        """Returns the view to use for a specified object."""
         view = ""
         if item is not None:
             view = item.get_view()
@@ -289,8 +274,7 @@ class CustomEditor(Editor):
         )
 
     def update_object(self, event):
-        """ Handles the user selecting a new value from the combo box.
-        """
+        """Handles the user selecting a new value from the combo box."""
         name = event.GetString()
         for item in self.items:
             if name == item.get_name():
@@ -310,8 +294,8 @@ class CustomEditor(Editor):
                 break
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         # Attach the current object value to the control (for use by
         # DockWindowFeature):
@@ -341,7 +325,7 @@ class CustomEditor(Editor):
                 choice.SetValue(name)
 
     def resynch_editor(self):
-        """ Resynchronizes the contents of the editor when the object trait
+        """Resynchronizes the contents of the editor when the object trait
         changes externally to the editor.
         """
         panel = self._panel
@@ -422,28 +406,25 @@ class CustomEditor(Editor):
                 parent.SendSizeEvent()
 
     def error(self, excp):
-        """ Handles an error that occurs while setting the object's trait value.
-        """
+        """Handles an error that occurs while setting the object's trait value."""
         pass
 
     def get_error_control(self):
-        """ Returns the editor's control for indicating error status.
-        """
+        """Returns the editor's control for indicating error status."""
         return self._choice or self.control
 
     # -- UI preference save/restore interface ---------------------------------
 
     def restore_prefs(self, prefs):
-        """ Restores any saved user preference information associated with the
-            editor.
+        """Restores any saved user preference information associated with the
+        editor.
         """
         ui = self._ui
         if (ui is not None) and (prefs.get("id") == ui.id):
             ui.set_prefs(prefs.get("prefs"))
 
     def save_prefs(self):
-        """ Returns any user preference information associated with the editor.
-        """
+        """Returns any user preference information associated with the editor."""
         ui = self._ui
         if (ui is not None) and (ui.id != ""):
             return {"id": ui.id, "prefs": ui.get_prefs()}
@@ -453,8 +434,7 @@ class CustomEditor(Editor):
     # -- Drag and drop event handlers -----------------------------------------
 
     def wx_dropped_on(self, x, y, data, drag_result):
-        """ Handles a Python object being dropped on the tree.
-        """
+        """Handles a Python object being dropped on the tree."""
         for item in self.items:
             if item.is_droppable() and item.is_compatible(data):
                 if self._object_cache is not None:
@@ -465,8 +445,7 @@ class CustomEditor(Editor):
         return wx.DragNone
 
     def wx_drag_over(self, x, y, data, drag_result):
-        """ Handles a Python object being dragged over the tree.
-        """
+        """Handles a Python object being dragged over the tree."""
         for item in self.items:
             if item.is_droppable() and item.is_compatible(data):
                 return drag_result
@@ -480,7 +459,7 @@ class CustomEditor(Editor):
 
 
 class SimpleEditor(CustomEditor):
-    """ Simple style of editor for instances, which displays a button. Clicking
+    """Simple style of editor for instances, which displays a button. Clicking
     the button displays a dialog box in which the instance can be edited.
     """
 
@@ -488,25 +467,30 @@ class SimpleEditor(CustomEditor):
     orientation = wx.HORIZONTAL
     extra = 2
 
+    #: The ui instance for the currently open editor dialog
+    _dialog_ui = Instance("traitsui.ui.UI")
+
     def create_editor(self, parent, sizer):
-        """ Creates the editor control (a button).
-        """
+        """Creates the editor control (a button)."""
         self._button = button = wx.Button(parent, -1, "")
         sizer.Add(button, 1, wx.EXPAND | wx.LEFT, 5)
         button.Bind(wx.EVT_BUTTON, self.edit_instance, id=button.GetId())
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
         button = self._button
         if button is not None:
             button.Bind(wx.EVT_BUTTON, None, id=button.GetId())
 
-        super(SimpleEditor, self).dispose()
+        if self._dialog_ui is not None:
+            self._dialog_ui.dispose()
+            self._dialog_ui = None
+
+        super().dispose()
 
     def edit_instance(self, event):
-        """ Edit the contents of the object trait when the user clicks the
-            button.
+        """Edit the contents of the object trait when the user clicks the
+        button.
         """
         # Create the user interface:
         factory = self.factory
@@ -527,10 +511,11 @@ class SimpleEditor(CustomEditor):
             # have its own:
             if ui.history is None:
                 ui.history = self.ui.history
+        self._dialog_ui = ui
 
     def resynch_editor(self):
-        """ Resynchronizes the contents of the editor when the object trait
-            changes externally to the editor.
+        """Resynchronizes the contents of the editor when the object trait
+        changes externally to the editor.
         """
         button = self._button
         if button is not None:
