@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -22,7 +22,6 @@ from .editor import Editor
 
 
 class _ShellEditor(BaseShellEditor, Editor):
-    """ Editor that displays an interactive Python shell.
-    """
+    """Editor that displays an interactive Python shell."""
 
     pass
